@@ -4,8 +4,7 @@ from matplotlib import rcParamsDefault
 
 
 def rcparam_role(name, rawtext, text, lineno, inliner, options={}, content=[]):
-    param = rcParamsDefault.get(text)
-    rendered = nodes.Text(f'rcParams["{text}"] = {param!r}')
+    rendered = nodes.Text(f'rcParams["{text}"]')
 
     source = inliner.document.attributes['source'].replace(sep, '/')
     rel_source = source.split('/doc/', 1)[1]
@@ -16,7 +15,14 @@ def rcparam_role(name, rawtext, text, lineno, inliner, options={}, content=[]):
               f"?highlight={text}#a-sample-matplotlibrc-file")
 
     ref = nodes.reference(rawtext, rendered, refuri=refuri)
-    return [nodes.literal('', '', ref)], []
+    node_list = [nodes.literal('', '', ref)]
+    if text in rcParamsDefault:
+        node_list.extend([
+            nodes.Text(' (default: '),
+            nodes.literal('', repr(rcParamsDefault[text])),
+            nodes.Text(')'),
+            ])
+    return node_list, []
 
 
 def setup(app):
