@@ -15,18 +15,13 @@ x = np.arange(0, 2*np.pi, 0.01)
 line, = ax.plot(x, np.sin(x))
 
 
-def init():  # only required for blitting to give a clean slate.
-    line.set_ydata([np.nan] * len(x))
-    return line,
-
-
 def animate(i):
-    line.set_ydata(np.sin(x + i / 100))  # update the data.
+    line.set_ydata(np.sin(x + i / 50))  # update the data.
     return line,
 
 
 ani = animation.FuncAnimation(
-    fig, animate, init_func=init, interval=2, blit=True, save_count=50)
+    fig, animate, interval=20, blit=True, save_count=50)
 
 # To save the animation, use e.g.
 #
@@ -34,8 +29,8 @@ ani = animation.FuncAnimation(
 #
 # or
 #
-# from matplotlib.animation import FFMpegWriter
-# writer = FFMpegWriter(fps=15, metadata=dict(artist='Me'), bitrate=1800)
+# writer = animation.FFMpegWriter(
+#     fps=15, metadata=dict(artist='Me'), bitrate=1800)
 # ani.save("movie.mp4", writer=writer)
 
 plt.show()
