@@ -5,23 +5,15 @@ Demo Axes RGB
 
 RGBAxes to show RGB composite images.
 """
-import numpy as np
-import matplotlib.pyplot as plt
 
+import numpy as np
+from matplotlib import cbook
+import matplotlib.pyplot as plt
 from mpl_toolkits.axes_grid1.axes_rgb import make_rgb_axes, RGBAxes
 
 
-def get_demo_image():
-    from matplotlib.cbook import get_sample_data
-    f = get_sample_data("axes_grid/bivariate_normal.npy", asfileobj=False)
-    z = np.load(f)
-    # z is a numpy array of 15x15
-    return z, (-3, 4, -4, 3)
-
-
 def get_rgb():
-    Z, extent = get_demo_image()
-
+    Z = cbook.get_sample_data("axes_grid/bivariate_normal.npy", np_load=True)
     Z[Z < 0] = 0.
     Z = Z / Z.max()
 
@@ -34,7 +26,7 @@ def get_rgb():
 
 def make_cube(r, g, b):
     ny, nx = r.shape
-    R = np.zeros([ny, nx, 3], dtype="d")
+    R = np.zeros((ny, nx, 3))
     R[:, :, 0] = r
     G = np.zeros_like(R)
     G[:, :, 1] = g
@@ -46,42 +38,34 @@ def make_cube(r, g, b):
     return R, G, B, RGB
 
 
-def demo_rgb():
+def demo_rgb1():
+    fig = plt.figure()
+    ax = RGBAxes(fig, [0.1, 0.1, 0.8, 0.8], pad=0.0)
+    r, g, b = get_rgb()
+    ax.imshow_rgb(r, g, b)
+
+
+def demo_rgb2():
     fig, ax = plt.subplots()
     ax_r, ax_g, ax_b = make_rgb_axes(ax, pad=0.02)
 
     r, g, b = get_rgb()
     im_r, im_g, im_b, im_rgb = make_cube(r, g, b)
-    kwargs = dict(origin="lower", interpolation="nearest")
-    ax.imshow(im_rgb, **kwargs)
-    ax_r.imshow(im_r, **kwargs)
-    ax_g.imshow(im_g, **kwargs)
-    ax_b.imshow(im_b, **kwargs)
+    ax.imshow(im_rgb)
+    ax_r.imshow(im_r)
+    ax_g.imshow(im_g)
+    ax_b.imshow(im_b)
 
-
-def demo_rgb2():
-    fig = plt.figure()
-    ax = RGBAxes(fig, [0.1, 0.1, 0.8, 0.8], pad=0.0)
-
-    r, g, b = get_rgb()
-    kwargs = dict(origin="lower", interpolation="nearest")
-    ax.imshow_rgb(r, g, b, **kwargs)
-
-    ax.RGB.set_xlim(0., 9.5)
-    ax.RGB.set_ylim(0.9, 10.6)
-
-    for ax1 in [ax.RGB, ax.R, ax.G, ax.B]:
-        ax1.tick_params(axis='both', direction='in')
-        for sp1 in ax1.spines.values():
+    for ax in fig.axes:
+        ax.tick_params(axis='both', direction='in')
+        for sp1 in ax.spines.values():
             sp1.set_color("w")
-        for tick in ax1.xaxis.get_major_ticks() + ax1.yaxis.get_major_ticks():
+        for tick in ax.xaxis.get_major_ticks() + ax.yaxis.get_major_ticks():
             tick.tick1line.set_markeredgecolor("w")
             tick.tick2line.set_markeredgecolor("w")
 
-    return ax
 
-
-demo_rgb()
+demo_rgb1()
 demo_rgb2()
 
 plt.show()
