@@ -10,7 +10,11 @@ import numpy as np
 import matplotlib.pyplot as plt
 
 
-class IndexTracker(object):
+# Fixing random state for reproducibility
+np.random.seed(19680801)
+
+
+class IndexTracker:
     def __init__(self, ax, X):
         self.ax = ax
         ax.set_title('use scroll wheel to navigate images')
@@ -22,7 +26,7 @@ class IndexTracker(object):
         self.im = ax.imshow(self.X[:, :, self.ind])
         self.update()
 
-    def onscroll(self, event):
+    def on_scroll(self, event):
         print("%s %s" % (event.button, event.step))
         if event.button == 'up':
             self.ind = (self.ind + 1) % self.slices
@@ -43,5 +47,5 @@ X = np.random.rand(20, 20, 40)
 tracker = IndexTracker(ax, X)
 
 
-fig.canvas.mpl_connect('scroll_event', tracker.onscroll)
+fig.canvas.mpl_connect('scroll_event', tracker.on_scroll)
 plt.show()
