@@ -10,7 +10,7 @@ import numpy as np
 import matplotlib.pyplot as plt
 
 
-def press(event):
+def on_press(event):
     print('press', event.key)
     sys.stdout.flush()
     if event.key == 'x':
@@ -24,7 +24,7 @@ np.random.seed(19680801)
 
 fig, ax = plt.subplots()
 
-fig.canvas.mpl_connect('key_press_event', press)
+fig.canvas.mpl_connect('key_press_event', on_press)
 
 ax.plot(np.random.rand(12), np.random.rand(12), 'go')
 xl = ax.set_xlabel('easy come, easy go')
