@@ -12,7 +12,7 @@ import numpy as np
 x = np.linspace(0.1, 2 * np.pi, 41)
 y = np.exp(np.sin(x))
 
-plt.stem(x, y, use_line_collection=True)
+plt.stem(x, y)
 plt.show()
 
 #############################################################################
@@ -24,7 +24,7 @@ plt.show()
 # control adapt the line objects returned by `~.pyplot`.
 
 markerline, stemlines, baseline = plt.stem(
-    x, y, linefmt='grey', markerfmt='D', bottom=1.1, use_line_collection=True)
+    x, y, linefmt='grey', markerfmt='D', bottom=1.1)
 markerline.set_markerfacecolor('none')
 plt.show()
 
