@@ -3,8 +3,8 @@
 Demonstrates plotting contour (level) curves in 3D
 ==================================================
 
-This is like a contour plot in 2D except that the f(x,y)=c curve is plotted
-on the plane z=c.
+This is like a contour plot in 2D except that the ``f(x, y)=c`` curve is
+plotted on the plane ``z=c``.
 """
 
 from mpl_toolkits.mplot3d import axes3d
@@ -18,6 +18,6 @@ X, Y, Z = axes3d.get_test_data(0.05)
 # Plot contour curves
 cset = ax.contour(X, Y, Z, cmap=cm.coolwarm)
 
-ax.clabel(cset, fontsize=9, inline=1)
+ax.clabel(cset, fontsize=9, inline=True)
 
 plt.show()
