@@ -1,13 +1,10 @@
-'''
+"""
 ================
 Parametric Curve
 ================
 
 This example demonstrates plotting a parametric curve in 3D.
-'''
-
-# This import registers the 3D projection, but is otherwise unused.
-from mpl_toolkits.mplot3d import Axes3D  # noqa: F401 unused import
+"""
 
 import numpy as np
 import matplotlib.pyplot as plt
