@@ -1,4 +1,4 @@
-'''
+"""
 =========================
 Automatic Text Offsetting
 =========================
@@ -11,10 +11,7 @@ from the center of the plot.
 This demo triggers the display of the offset text for the x and
 y axis by adding 1e5 to X and Y. Anything less would not
 automatically trigger it.
-'''
-
-# This import registers the 3D projection, but is otherwise unused.
-from mpl_toolkits.mplot3d import Axes3D  # noqa: F401 unused import
+"""
 
 import matplotlib.pyplot as plt
 import numpy as np
