@@ -8,12 +8,8 @@ graph. In this example polygons are semi-transparent, creating a sort
 of 'jagged stained glass' effect.
 """
 
-# This import registers the 3D projection, but is otherwise unused.
-from mpl_toolkits.mplot3d import Axes3D  # noqa: F401 unused import
-
 from matplotlib.collections import PolyCollection
 import matplotlib.pyplot as plt
-from matplotlib import colors as mcolors
 import numpy as np
 
 # Fixing random state for reproducibility
@@ -31,7 +27,8 @@ def polygon_under_graph(xlist, ylist):
 fig = plt.figure()
 ax = fig.gca(projection='3d')
 
-# Make verts a list, verts[i] will be a list of (x,y) pairs defining polygon i
+# Make verts a list such that verts[i] is a list of (x, y) pairs defining
+# polygon i.
 verts = []
 
 # Set up the x sequence
