@@ -1,13 +1,10 @@
-'''
+"""
 ========================
 3D surface (solid color)
 ========================
 
 Demonstrates a very basic plot of a 3D surface using a solid color.
-'''
-
-# This import registers the 3D projection, but is otherwise unused.
-from mpl_toolkits.mplot3d import Axes3D  # noqa: F401 unused import
+"""
 
 import matplotlib.pyplot as plt
 import numpy as np
