@@ -1,13 +1,10 @@
-'''
+"""
 =========================
 3D surface (checkerboard)
 =========================
 
 Demonstrates plotting a 3D surface colored in a checkerboard pattern.
-'''
-
-# This import registers the 3D projection, but is otherwise unused.
-from mpl_toolkits.mplot3d import Axes3D  # noqa: F401 unused import
+"""
 
 import matplotlib.pyplot as plt
 from matplotlib.ticker import LinearLocator
@@ -39,6 +36,6 @@ surf = ax.plot_surface(X, Y, Z, facecolors=colors, linewidth=0)
 
 # Customize the z axis.
 ax.set_zlim(-1, 1)
-ax.w_zaxis.set_major_locator(LinearLocator(6))
+ax.zaxis.set_major_locator(LinearLocator(6))
 
 plt.show()
