@@ -1,4 +1,4 @@
-'''
+"""
 =================================
 3D surface with polar coordinates
 =================================
@@ -8,10 +8,7 @@ Uses the reversed version of the YlGnBu color map.
 Also demonstrates writing axis labels with latex math mode.
 
 Example contributed by Armin Moser.
-'''
-
-# This import registers the 3D projection, but is otherwise unused.
-from mpl_toolkits.mplot3d import Axes3D  # noqa: F401 unused import
+"""
 
 import matplotlib.pyplot as plt
 import numpy as np
