@@ -1,18 +1,15 @@
-'''
+"""
 =======================================================
 3D voxel / volumetric plot with cylindrical coordinates
 =======================================================
 
-Demonstrates using the ``x, y, z`` arguments of ``ax.voxels``.
-'''
+Demonstrates using the *x*, *y*, *z* arguments of `.Axes3D.voxels`.
+"""
 
 import matplotlib.pyplot as plt
 import matplotlib.colors
 import numpy as np
 
-# This import registers the 3D projection, but is otherwise unused.
-from mpl_toolkits.mplot3d import Axes3D  # noqa: F401 unused import
-
 
 def midpoints(x):
     sl = ()
