@@ -1,12 +1,10 @@
 """
-=====================
-Whats New 1 Subplot3d
-=====================
+======================
+What's New 1 Subplot3d
+======================
 
 Create two three-dimensional plots in the same figure.
 """
-# This import registers the 3D projection, but is otherwise unused.
-from mpl_toolkits.mplot3d import Axes3D  # noqa: F401 unused import
 
 from matplotlib import cm
 #from matplotlib.ticker import LinearLocator, FixedLocator, FormatStrFormatter
@@ -25,8 +23,8 @@ surf = ax.plot_surface(X, Y, Z, rstride=1, cstride=1, cmap=cm.viridis,
                        linewidth=0, antialiased=False)
 ax.set_zlim3d(-1.01, 1.01)
 
-#ax.w_zaxis.set_major_locator(LinearLocator(10))
-#ax.w_zaxis.set_major_formatter(FormatStrFormatter('%.03f'))
+#ax.zaxis.set_major_locator(LinearLocator(10))
+#ax.zaxis.set_major_formatter(FormatStrFormatter('%.03f'))
 
 fig.colorbar(surf, shrink=0.5, aspect=5)
 
