@@ -1,11 +1,12 @@
-"""
+r"""
 ===================================
 Using a ttf font file in Matplotlib
 ===================================
 
 Although it is usually not a good idea to explicitly point to a single ttf file
-for a font instance, you can do so using the `font_manager.FontProperties`
-*fname* argument.
+for a font instance, you can do so by passing a `pathlib.Path` instance as the
+*font* parameter.  Note that passing paths as `str`\s is intentionally not
+supported, but you can simply wrap `str`\s in `pathlib.Path`\s as needed.
 
 Here, we use the Computer Modern roman font (``cmr10``) shipped with
 Matplotlib.
@@ -15,16 +16,15 @@ For a more flexible solution, see
 :doc:`/gallery/text_labels_and_annotations/fonts_demo`.
 """
 
-import os
-from matplotlib import font_manager as fm, rcParams
+from pathlib import Path
+
+import matplotlib as mpl
 import matplotlib.pyplot as plt
 
 fig, ax = plt.subplots()
 
-fpath = os.path.join(rcParams["datapath"], "fonts/ttf/cmr10.ttf")
-prop = fm.FontProperties(fname=fpath)
-fname = os.path.split(fpath)[1]
-ax.set_title('This is a special font: {}'.format(fname), fontproperties=prop)
+fpath = Path(mpl.get_data_path(), "fonts/ttf/cmr10.ttf")
+ax.set_title(f'This is a special font: {fpath.name}', font=fpath)
 ax.set_xlabel('This is the default font')
 
 plt.show()
@@ -41,5 +41,4 @@ plt.show()
 # in this example:
 
 import matplotlib
-matplotlib.font_manager.FontProperties
 matplotlib.axes.Axes.set_title
