@@ -17,11 +17,13 @@ coordinate system, as shown in the example below.
 import matplotlib.pyplot as plt
 import numpy as np
 
+fig, ax = plt.subplots()
+
 # Plot diagonal line (45 degrees)
-h = plt.plot(np.arange(0, 10), np.arange(0, 10))
+h = ax.plot(range(0, 10), range(0, 10))
 
 # set limits so that it no longer looks on screen to be 45 degrees
-plt.xlim([-10, 20])
+ax.set_xlim([-10, 20])
 
 # Locations to plot text
 l1 = np.array((1, 1))
@@ -29,13 +31,12 @@ l2 = np.array((5, 5))
 
 # Rotate angle
 angle = 45
-trans_angle = plt.gca().transData.transform_angles(np.array((45,)),
-                                                   l2.reshape((1, 2)))[0]
+trans_angle = ax.transData.transform_angles([45], l2.reshape((1, 2)))[0]
 
 # Plot text
-th1 = plt.text(l1[0], l1[1], 'text not rotated correctly', fontsize=16,
-               rotation=angle, rotation_mode='anchor')
-th2 = plt.text(l2[0], l2[1], 'text rotated correctly', fontsize=16,
-               rotation=trans_angle, rotation_mode='anchor')
+th1 = ax.text(*l1, 'text not rotated correctly', fontsize=16,
+              rotation=angle, rotation_mode='anchor')
+th2 = ax.text(*l2, 'text rotated correctly', fontsize=16,
+              rotation=trans_angle, rotation_mode='anchor')
 
 plt.show()
