@@ -4,9 +4,10 @@ Spines
 ======
 
 This demo compares:
-    - normal axes, with spines on all four sides;
-    - an axes with spines only on the left and bottom;
-    - an axes using custom bounds to limit the extent of the spine.
+
+- normal axes, with spines on all four sides;
+- an axes with spines only on the left and bottom;
+- an axes using custom bounds to limit the extent of the spine.
 """
 import numpy as np
 import matplotlib.pyplot as plt
@@ -15,7 +16,8 @@ import matplotlib.pyplot as plt
 x = np.linspace(0, 2 * np.pi, 100)
 y = 2 * np.sin(x)
 
-fig, (ax0, ax1, ax2) = plt.subplots(nrows=3)
+# Constrained layout makes sure the labels don't overlap the axes.
+fig, (ax0, ax1, ax2) = plt.subplots(nrows=3, constrained_layout=True)
 
 ax0.plot(x, y)
 ax0.set_title('normal spines')
@@ -41,6 +43,4 @@ ax2.spines['top'].set_visible(False)
 ax2.yaxis.set_ticks_position('left')
 ax2.xaxis.set_ticks_position('bottom')
 
-# Tweak spacing between subplots to prevent labels from overlapping
-plt.subplots_adjust(hspace=0.5)
 plt.show()
