@@ -21,20 +21,20 @@ win.connect("delete-event", Gtk.main_quit)
 win.set_default_size(400, 300)
 win.set_title("Embedding in GTK")
 
-f = Figure(figsize=(5, 4), dpi=100)
-a = f.add_subplot(111)
+fig = Figure(figsize=(5, 4), dpi=100)
+ax = fig.add_subplot(111)
 t = np.arange(0.0, 3.0, 0.01)
 s = np.sin(2*np.pi*t)
-a.plot(t, s)
+ax.plot(t, s)
 
 sw = Gtk.ScrolledWindow()
 win.add(sw)
 # A scrolled window border goes outside the scrollbars and viewport
 sw.set_border_width(10)
 
-canvas = FigureCanvas(f)  # a Gtk.DrawingArea
+canvas = FigureCanvas(fig)  # a Gtk.DrawingArea
 canvas.set_size_request(800, 600)
-sw.add_with_viewport(canvas)
+sw.add(canvas)
 
 win.show_all()
 Gtk.main()
