@@ -59,4 +59,7 @@ def colorfunc(label):
     fig.canvas.draw_idle()
 radio.on_clicked(colorfunc)
 
+# Initialize plot with correct initial active value
+colorfunc(radio.value_selected)
+
 plt.show()
