@@ -11,70 +11,72 @@ These tools are used by `matplotlib.backend_managers.ToolManager`
     `matplotlib.backend_managers.ToolManager`
 """
 
+from enum import IntEnum
+import logging
 import re
 import time
-import logging
 from types import SimpleNamespace
+import uuid
 from weakref import WeakKeyDictionary
 
 import numpy as np
 
-from matplotlib import rcParams
+import matplotlib as mpl
 from matplotlib._pylab_helpers import Gcf
 import matplotlib.cbook as cbook
 
 _log = logging.getLogger(__name__)
 
 
-class Cursors(object):
-    """Simple namespace for cursor reference"""
+class Cursors(IntEnum):  # Must subclass int for the macOS backend.
+    """Backend-independent cursor types."""
     HAND, POINTER, SELECT_REGION, MOVE, WAIT = range(5)
-cursors = Cursors()
+cursors = Cursors  # Backcompat.
 
 # Views positions tool
 _views_positions = 'viewpos'
 
 
-class ToolBase(object):
+class ToolBase:
     """
-    Base tool class
+    Base tool class.
 
     A base tool, only implements `trigger` method or not method at all.
-    The tool is instantiated by `matplotlib.backend_managers.ToolManager`
+    The tool is instantiated by `matplotlib.backend_managers.ToolManager`.
 
     Attributes
     ----------
     toolmanager : `matplotlib.backend_managers.ToolManager`
-        ToolManager that controls this Tool
+        ToolManager that controls this Tool.
     figure : `FigureCanvas`
-        Figure instance that is affected by this Tool
-    name : string
+        Figure instance that is affected by this Tool.
+    name : str
         Used as **Id** of the tool, has to be unique among tools of the same
-        ToolManager
+        ToolManager.
     """
 
     default_keymap = None
     """
-    Keymap to associate with this tool
+    Keymap to associate with this tool.
 
     **String**: List of comma separated keys that will be used to call this
-    tool when the keypress event of *self.figure.canvas* is emitted
+    tool when the keypress event of ``self.figure.canvas`` is emitted.
     """
 
     description = None
     """
-    Description of the Tool
+    Description of the Tool.
 
     **String**: If the Tool is included in the Toolbar this text is used
-    as a Tooltip
+    as a Tooltip.
     """
 
     image = None
     """
-    Filename of the image
+    Filename of the image.
 
     **String**: Filename of the image to use in the toolbar. If None, the
-    `name` is used as a label in the toolbar button
+    *name* is used as a label in the toolbar button.
     """
 
     def __init__(self, toolmanager, name):
@@ -114,82 +116,81 @@ class ToolBase(object):
 
     def set_figure(self, figure):
         """
-        Assign a figure to the tool
+        Assign a figure to the tool.
 
         Parameters
         ----------
-        figure : `Figure`
+        figure : `.Figure`
         """
         self._figure = figure
 
     def trigger(self, sender, event, data=None):
         """
-        Called when this tool gets used
+        Called when this tool gets used.
 
         This method is called by
-        `matplotlib.backend_managers.ToolManager.trigger_tool`
+        `matplotlib.backend_managers.ToolManager.trigger_tool`.
 
         Parameters
         ----------
-        event : `Event`
-            The Canvas event that caused this tool to be called
+        event : `.Event`
+            The canvas event that caused this tool to be called.
         sender : object
-            Object that requested the tool to be triggered
+            Object that requested the tool to be triggered.
         data : object
-            Extra data
+            Extra data.
         """
-
         pass
 
     @property
     def name(self):
-        """Tool Id"""
+        """Tool Id."""
         return self._name
 
     def destroy(self):
         """
-        Destroy the tool
+        Destroy the tool.
 
         This method is called when the tool is removed by
-        `matplotlib.backend_managers.ToolManager.remove_tool`
+        `matplotlib.backend_managers.ToolManager.remove_tool`.
         """
         pass
 
 
 class ToolToggleBase(ToolBase):
     """
-    Toggleable tool
+    Toggleable tool.
 
-    Every time it is triggered, it switches between enable and disable
+    Every time it is triggered, it switches between enable and disable.
 
     Parameters
     ----------
     ``*args``
-        Variable length argument to be used by the Tool
+        Variable length argument to be used by the Tool.
     ``**kwargs``
         `toggled` if present and True, sets the initial state of the Tool
         Arbitrary keyword arguments to be consumed by the Tool
     """
 
     radio_group = None
-    """Attribute to group 'radio' like tools (mutually exclusive)
+    """Attribute to group 'radio' like tools (mutually exclusive).
 
     **String** that identifies the group or **None** if not belonging to a
-    group
+    group.
     """
 
     cursor = None
-    """Cursor to use when the tool is active"""
+    """Cursor to use when the tool is active."""
 
     default_toggled = False
-    """Default of toggled state"""
+    """Default of toggled state."""
 
     def __init__(self, *args, **kwargs):
         self._toggled = kwargs.pop('toggled', self.default_toggled)
         ToolBase.__init__(self, *args, **kwargs)
 
     def trigger(self, sender, event, data=None):
-        """Calls `enable` or `disable` based on `toggled` value"""
+        """Calls `enable` or `disable` based on `toggled` value."""
         if self._toggled:
             self.disable(event)
         else:
@@ -198,30 +199,30 @@ class ToolToggleBase(ToolBase):
 
     def enable(self, event=None):
         """
-        Enable the toggle tool
+        Enable the toggle tool.
 
-        `trigger` calls this method when `toggled` is False
+        `trigger` calls this method when `toggled` is False.
         """
         pass
 
     def disable(self, event=None):
         """
-        Disable the toggle tool
+        Disable the toggle tool.
 
         `trigger` call this method when `toggled` is True.
 
-        This can happen in different circumstances
+        This can happen in different circumstances.
 
-        * Click on the toolbar tool button
-        * Call to `matplotlib.backend_managers.ToolManager.trigger_tool`
+        * Click on the toolbar tool button.
+        * Call to `matplotlib.backend_managers.ToolManager.trigger_tool`.
         * Another `ToolToggleBase` derived tool is triggered
-          (from the same `ToolManager`)
+          (from the same `.ToolManager`).
         """
         pass
 
     @property
     def toggled(self):
-        """State of the toggled tool"""
+        """State of the toggled tool."""
 
         return self._toggled
 
@@ -246,14 +247,14 @@ class ToolToggleBase(ToolBase):
 
 class SetCursorBase(ToolBase):
     """
-    Change to the current cursor while inaxes
+    Change to the current cursor while inaxes.
 
     This tool, keeps track of all `ToolToggleBase` derived tools, and calls
-    set_cursor when a tool gets triggered
+    `set_cursor` when a tool gets triggered.
     """
     def __init__(self, *args, **kwargs):
         ToolBase.__init__(self, *args, **kwargs)
-        self._idDrag = None
+        self._id_drag = None
         self._cursor = None
         self._default_cursor = cursors.POINTER
         self._last_cursor = self._default_cursor
@@ -265,11 +266,11 @@ class SetCursorBase(ToolBase):
             self._add_tool(tool)
 
     def set_figure(self, figure):
-        if self._idDrag:
-            self.canvas.mpl_disconnect(self._idDrag)
+        if self._id_drag:
+            self.canvas.mpl_disconnect(self._id_drag)
         ToolBase.set_figure(self, figure)
         if figure:
-            self._idDrag = self.canvas.mpl_connect(
+            self._id_drag = self.canvas.mpl_connect(
                 'motion_notify_event', self._set_cursor_cbk)
 
     def _tool_trigger_cbk(self, event):
@@ -308,33 +309,33 @@ class SetCursorBase(ToolBase):
 
     def set_cursor(self, cursor):
         """
-        Set the cursor
+        Set the cursor.
 
-        This method has to be implemented per backend
+        This method has to be implemented per backend.
         """
         raise NotImplementedError
 
 
 class ToolCursorPosition(ToolBase):
     """
-    Send message with the current pointer position
+    Send message with the current pointer position.
 
-    This tool runs in the background reporting the position of the cursor
+    This tool runs in the background reporting the position of the cursor.
     """
     def __init__(self, *args, **kwargs):
-        self._idDrag = None
+        self._id_drag = None
         ToolBase.__init__(self, *args, **kwargs)
 
     def set_figure(self, figure):
-        if self._idDrag:
-            self.canvas.mpl_disconnect(self._idDrag)
+        if self._id_drag:
+            self.canvas.mpl_disconnect(self._id_drag)
         ToolBase.set_figure(self, figure)
         if figure:
-            self._idDrag = self.canvas.mpl_connect(
+            self._id_drag = self.canvas.mpl_connect(
                 'motion_notify_event', self.send_message)
 
     def send_message(self, event):
-        """Call `matplotlib.backend_managers.ToolManager.message_event`"""
+        """Call `matplotlib.backend_managers.ToolManager.message_event`."""
         if self.toolmanager.messagelock.locked():
             return
 
@@ -363,9 +364,9 @@ class ToolCursorPosition(ToolBase):
 
 
 class RubberbandBase(ToolBase):
-    """Draw and remove rubberband"""
+    """Draw and remove a rubberband."""
     def trigger(self, sender, event, data):
-        """Call `draw_rubberband` or `remove_rubberband` based on data"""
+        """Call `draw_rubberband` or `remove_rubberband` based on data."""
         if not self.figure.canvas.widgetlock.available(sender):
             return
         if data is not None:
@@ -375,155 +376,106 @@ class RubberbandBase(ToolBase):
 
     def draw_rubberband(self, *data):
         """
-        Draw rubberband
+        Draw rubberband.
 
-        This method must get implemented per backend
+        This method must get implemented per backend.
         """
         raise NotImplementedError
 
     def remove_rubberband(self):
         """
-        Remove rubberband
+        Remove rubberband.
 
-        This method should get implemented per backend
+        This method should get implemented per backend.
         """
         pass
 
 
 class ToolQuit(ToolBase):
-    """Tool to call the figure manager destroy method"""
+    """Tool to call the figure manager destroy method."""
 
     description = 'Quit the figure'
-    default_keymap = rcParams['keymap.quit']
+    default_keymap = mpl.rcParams['keymap.quit']
 
     def trigger(self, sender, event, data=None):
         Gcf.destroy_fig(self.figure)
 
 
 class ToolQuitAll(ToolBase):
-    """Tool to call the figure manager destroy method"""
+    """Tool to call the figure manager destroy method."""
 
     description = 'Quit all figures'
-    default_keymap = rcParams['keymap.quit_all']
+    default_keymap = mpl.rcParams['keymap.quit_all']
 
     def trigger(self, sender, event, data=None):
         Gcf.destroy_all()
 
 
-class ToolEnableAllNavigation(ToolBase):
-    """Tool to enable all axes for toolmanager interaction"""
+class _ToolEnableAllNavigation(ToolBase):
+    """Tool to enable all axes for toolmanager interaction."""
 
     description = 'Enable all axes toolmanager'
-    default_keymap = rcParams['keymap.all_axes']
+    default_keymap = mpl.rcParams['keymap.all_axes']
 
     def trigger(self, sender, event, data=None):
-        if event.inaxes is None:
-            return
-
-        for a in self.figure.get_axes():
-            if (event.x is not None and event.y is not None
-                    and a.in_axes(event)):
-                a.set_navigate(True)
+        mpl.backend_bases.key_press_handler(event, self.figure.canvas, None)
 
 
-class ToolEnableNavigation(ToolBase):
-    """Tool to enable a specific axes for toolmanager interaction"""
+@cbook.deprecated("3.3")
+class ToolEnableAllNavigation(_ToolEnableAllNavigation):
+    pass
+
+
+class _ToolEnableNavigation(ToolBase):
+    """Tool to enable a specific axes for toolmanager interaction."""
 
     description = 'Enable one axes toolmanager'
-    default_keymap = (1, 2, 3, 4, 5, 6, 7, 8, 9)
+    default_keymap = ('1', '2', '3', '4', '5', '6', '7', '8', '9')
 
     def trigger(self, sender, event, data=None):
-        if event.inaxes is None:
-            return
-
-        n = int(event.key) - 1
-        if n < len(self.figure.get_axes()):
-            for i, a in enumerate(self.figure.get_axes()):
-                if (event.x is not None and event.y is not None
-                        and a.in_axes(event)):
-                    a.set_navigate(i == n)
+        mpl.backend_bases.key_press_handler(event, self.figure.canvas, None)
 
 
-class _ToolGridBase(ToolBase):
-    """Common functionality between ToolGrid and ToolMinorGrid."""
-
-    _cycle = [(False, False), (True, False), (True, True), (False, True)]
-
-    def trigger(self, sender, event, data=None):
-        ax = event.inaxes
-        if ax is None:
-            return
-        try:
-            x_state, x_which, y_state, y_which = self._get_next_grid_states(ax)
-        except ValueError:
-            pass
-        else:
-            ax.grid(x_state, which=x_which, axis="x")
-            ax.grid(y_state, which=y_which, axis="y")
-            ax.figure.canvas.draw_idle()
-
-    @staticmethod
-    def _get_uniform_grid_state(ticks):
-        """
-        Check whether all grid lines are in the same visibility state.
-
-        Returns True/False if all grid lines are on or off, None if they are
-        not all in the same state.
-        """
-        if all(tick.gridline.get_visible() for tick in ticks):
-            return True
-        elif not any(tick.gridline.get_visible() for tick in ticks):
-            return False
-        else:
-            return None
+@cbook.deprecated("3.3")
+class ToolEnableNavigation(_ToolEnableNavigation):
+    pass
 
 
-class ToolGrid(_ToolGridBase):
-    """Tool to toggle the major grids of the figure"""
+class ToolGrid(ToolBase):
+    """Tool to toggle the major grids of the figure."""
 
     description = 'Toggle major grids'
-    default_keymap = rcParams['keymap.grid']
+    default_keymap = mpl.rcParams['keymap.grid']
 
-    def _get_next_grid_states(self, ax):
-        if None in map(self._get_uniform_grid_state,
-                       [ax.xaxis.minorTicks, ax.yaxis.minorTicks]):
-            # Bail out if minor grids are not in a uniform state.
-            raise ValueError
-        x_state, y_state = map(self._get_uniform_grid_state,
-                               [ax.xaxis.majorTicks, ax.yaxis.majorTicks])
-        cycle = self._cycle
-        # Bail out (via ValueError) if major grids are not in a uniform state.
-        x_state, y_state = (
-            cycle[(cycle.index((x_state, y_state)) + 1) % len(cycle)])
-        return (x_state, "major" if x_state else "both",
-                y_state, "major" if y_state else "both")
+    def trigger(self, sender, event, data=None):
+        sentinel = str(uuid.uuid4())
+        # Trigger grid switching by temporarily setting :rc:`keymap.grid`
+        # to a unique key and sending an appropriate event.
+        with cbook._setattr_cm(event, key=sentinel), \
+             mpl.rc_context({'keymap.grid': sentinel}):
+            mpl.backend_bases.key_press_handler(event, self.figure.canvas)
 
 
-class ToolMinorGrid(_ToolGridBase):
-    """Tool to toggle the major and minor grids of the figure"""
+class ToolMinorGrid(ToolBase):
+    """Tool to toggle the major and minor grids of the figure."""
 
     description = 'Toggle major and minor grids'
-    default_keymap = rcParams['keymap.grid_minor']
+    default_keymap = mpl.rcParams['keymap.grid_minor']
 
-    def _get_next_grid_states(self, ax):
-        if None in map(self._get_uniform_grid_state,
-                       [ax.xaxis.majorTicks, ax.yaxis.majorTicks]):
-            # Bail out if major grids are not in a uniform state.
-            raise ValueError
-        x_state, y_state = map(self._get_uniform_grid_state,
-                               [ax.xaxis.minorTicks, ax.yaxis.minorTicks])
-        cycle = self._cycle
-        # Bail out (via ValueError) if minor grids are not in a uniform state.
-        x_state, y_state = (
-            cycle[(cycle.index((x_state, y_state)) + 1) % len(cycle)])
-        return x_state, "both", y_state, "both"
+    def trigger(self, sender, event, data=None):
+        sentinel = str(uuid.uuid4())
+        # Trigger grid switching by temporarily setting :rc:`keymap.grid_minor`
+        # to a unique key and sending an appropriate event.
+        with cbook._setattr_cm(event, key=sentinel), \
+             mpl.rc_context({'keymap.grid_minor': sentinel}):
+            mpl.backend_bases.key_press_handler(event, self.figure.canvas)
 
 
 class ToolFullScreen(ToolToggleBase):
-    """Tool to toggle full screen"""
+    """Tool to toggle full screen."""
 
     description = 'Toggle fullscreen mode'
-    default_keymap = rcParams['keymap.fullscreen']
+    default_keymap = mpl.rcParams['keymap.fullscreen']
 
     def enable(self, event):
         self.figure.canvas.manager.full_screen_toggle()
@@ -533,7 +485,7 @@ class ToolFullScreen(ToolToggleBase):
 
 
 class AxisScaleBase(ToolToggleBase):
-    """Base Tool to toggle between linear and logarithmic"""
+    """Base Tool to toggle between linear and logarithmic."""
 
     def trigger(self, sender, event, data=None):
         if event.inaxes is None:
@@ -550,20 +502,20 @@ class AxisScaleBase(ToolToggleBase):
 
 
 class ToolYScale(AxisScaleBase):
-    """Tool to toggle between linear and logarithmic scales on the Y axis"""
+    """Tool to toggle between linear and logarithmic scales on the Y axis."""
 
     description = 'Toggle scale Y axis'
-    default_keymap = rcParams['keymap.yscale']
+    default_keymap = mpl.rcParams['keymap.yscale']
 
     def set_scale(self, ax, scale):
         ax.set_yscale(scale)
 
 
 class ToolXScale(AxisScaleBase):
-    """Tool to toggle between linear and logarithmic scales on the X axis"""
+    """Tool to toggle between linear and logarithmic scales on the X axis."""
 
     description = 'Toggle scale X axis'
-    default_keymap = rcParams['keymap.xscale']
+    default_keymap = mpl.rcParams['keymap.xscale']
 
     def set_scale(self, ax, scale):
         ax.set_xscale(scale)
@@ -571,7 +523,7 @@ class ToolXScale(AxisScaleBase):
 
 class ToolViewsPositions(ToolBase):
     """
-    Auxiliary Tool to handle changes in views and positions
+    Auxiliary Tool to handle changes in views and positions.
 
     Runs in the background and should get used by all the tools that
     need to access the figure's history of views and positions, e.g.
@@ -590,7 +542,7 @@ class ToolViewsPositions(ToolBase):
         ToolBase.__init__(self, *args, **kwargs)
 
     def add_figure(self, figure):
-        """Add the current figure to the stack of views and positions"""
+        """Add the current figure to the stack of views and positions."""
 
         if figure not in self.views:
             self.views[figure] = cbook.Stack()
@@ -602,7 +554,7 @@ class ToolViewsPositions(ToolBase):
             figure.add_axobserver(lambda fig: self.update_home_views(fig))
 
     def clear(self, figure):
-        """Reset the axes stack"""
+        """Reset the axes stack."""
         if figure in self.views:
             self.views[figure].clear()
             self.positions[figure].clear()
@@ -642,7 +594,7 @@ class ToolViewsPositions(ToolBase):
 
     def push_current(self, figure=None):
         """
-        Push the current view limits and position onto their respective stacks
+        Push the current view limits and position onto their respective stacks.
         """
         if not figure:
             figure = self.figure
@@ -656,17 +608,17 @@ class ToolViewsPositions(ToolBase):
 
     def _axes_pos(self, ax):
         """
-        Return the original and modified positions for the specified axes
+        Return the original and modified positions for the specified axes.
 
         Parameters
         ----------
-        ax : (matplotlib.axes.AxesSubplot)
-        The axes to get the positions for
+        ax : matplotlib.axes.Axes
+            The `.Axes` to get the positions for.
 
         Returns
         -------
-        limits : (tuple)
-        A tuple of the original and modified positions
+        original_position, modified_position
+            A tuple of the original and modified positions.
         """
 
         return (ax.get_position(True).frozen(),
@@ -674,8 +626,8 @@ class ToolViewsPositions(ToolBase):
 
     def update_home_views(self, figure=None):
         """
-        Make sure that self.home_views has an entry for all axes present in the
-        figure
+        Make sure that ``self.home_views`` has an entry for all axes present
+        in the figure.
         """
 
         if not figure:
@@ -684,8 +636,14 @@ class ToolViewsPositions(ToolBase):
             if a not in self.home_views[figure]:
                 self.home_views[figure][a] = a._get_view()
 
+    @cbook.deprecated("3.3", alternative="self.figure.canvas.draw_idle()")
     def refresh_locators(self):
-        """Redraw the canvases, update the locators"""
+        """Redraw the canvases, update the locators."""
+        self._refresh_locators()
+
+    # Can be removed once Locator.refresh() is removed, and replaced by an
+    # inline call to self.figure.canvas.draw_idle().
+    def _refresh_locators(self):
         for a in self.figure.get_axes():
             xaxis = getattr(a, 'xaxis', None)
             yaxis = getattr(a, 'yaxis', None)
@@ -702,27 +660,27 @@ class ToolViewsPositions(ToolBase):
                 locators.append(zaxis.get_minor_locator())
 
             for loc in locators:
-                loc.refresh()
+                mpl.ticker._if_refresh_overridden_call_and_emit_deprec(loc)
         self.figure.canvas.draw_idle()
 
     def home(self):
-        """Recall the first view and position from the stack"""
+        """Recall the first view and position from the stack."""
         self.views[self.figure].home()
         self.positions[self.figure].home()
 
     def back(self):
-        """Back one step in the stack of views and positions"""
+        """Back one step in the stack of views and positions."""
         self.views[self.figure].back()
         self.positions[self.figure].back()
 
     def forward(self):
-        """Forward one step in the stack of views and positions"""
+        """Forward one step in the stack of views and positions."""
         self.views[self.figure].forward()
         self.positions[self.figure].forward()
 
 
 class ViewsPositionsBase(ToolBase):
-    """Base class for `ToolHome`, `ToolBack` and `ToolForward`"""
+    """Base class for `ToolHome`, `ToolBack` and `ToolForward`."""
 
     _on_trigger = None
 
@@ -734,49 +692,49 @@ class ViewsPositionsBase(ToolBase):
 
 
 class ToolHome(ViewsPositionsBase):
-    """Restore the original view lim"""
+    """Restore the original view limits."""
 
     description = 'Reset original view'
     image = 'home'
-    default_keymap = rcParams['keymap.home']
+    default_keymap = mpl.rcParams['keymap.home']
     _on_trigger = 'home'
 
 
 class ToolBack(ViewsPositionsBase):
-    """Move back up the view lim stack"""
+    """Move back up the view limits stack."""
 
     description = 'Back to previous view'
     image = 'back'
-    default_keymap = rcParams['keymap.back']
+    default_keymap = mpl.rcParams['keymap.back']
     _on_trigger = 'back'
 
 
 class ToolForward(ViewsPositionsBase):
-    """Move forward in the view lim stack"""
+    """Move forward in the view lim stack."""
 
     description = 'Forward to next view'
     image = 'forward'
-    default_keymap = rcParams['keymap.forward']
+    default_keymap = mpl.rcParams['keymap.forward']
     _on_trigger = 'forward'
 
 
 class ConfigureSubplotsBase(ToolBase):
-    """Base tool for the configuration of subplots"""
+    """Base tool for the configuration of subplots."""
 
     description = 'Configure subplots'
     image = 'subplots'
 
 
 class SaveFigureBase(ToolBase):
-    """Base tool for figure saving"""
+    """Base tool for figure saving."""
 
     description = 'Save the figure'
     image = 'filesave'
-    default_keymap = rcParams['keymap.save']
+    default_keymap = mpl.rcParams['keymap.save']
 
 
 class ZoomPanBase(ToolToggleBase):
-    """Base class for `ToolZoom` and `ToolPan`"""
+    """Base class for `ToolZoom` and `ToolPan`."""
     def __init__(self, *args):
         ToolToggleBase.__init__(self, *args)
         self._button_pressed = None
@@ -789,7 +747,7 @@ class ZoomPanBase(ToolToggleBase):
         self.lastscroll = time.time()-self.scrollthresh
 
     def enable(self, event):
-        """Connect press/release events and lock the canvas"""
+        """Connect press/release events and lock the canvas."""
         self.figure.canvas.widgetlock(self)
         self._idPress = self.figure.canvas.mpl_connect(
             'button_press_event', self._press)
@@ -799,7 +757,7 @@ class ZoomPanBase(ToolToggleBase):
             'scroll_event', self.scroll_zoom)
 
     def disable(self, event):
-        """Release the canvas and disconnect press/release events"""
+        """Release the canvas and disconnect press/release events."""
         self._cancel_action()
         self.figure.canvas.widgetlock.release(self)
         self.figure.canvas.mpl_disconnect(self._idPress)
@@ -840,11 +798,11 @@ class ZoomPanBase(ToolToggleBase):
 
 
 class ToolZoom(ZoomPanBase):
-    """Zoom to rectangle"""
+    """A Tool for zooming using a rectangle selector."""
 
     description = 'Zoom to rectangle'
     image = 'zoom_to_rect'
-    default_keymap = rcParams['keymap.zoom']
+    default_keymap = mpl.rcParams['keymap.zoom']
     cursor = cursors.SELECT_REGION
     radio_group = 'default'
 
@@ -856,7 +814,7 @@ class ToolZoom(ZoomPanBase):
         for zoom_id in self._ids_zoom:
             self.figure.canvas.mpl_disconnect(zoom_id)
         self.toolmanager.trigger_tool('rubberband', self)
-        self.toolmanager.get_tool(_views_positions).refresh_locators()
+        self.toolmanager.get_tool(_views_positions)._refresh_locators()
         self._xypress = None
         self._button_pressed = None
         self._ids_zoom = []
@@ -867,7 +825,7 @@ class ToolZoom(ZoomPanBase):
 
         # If we're already in the middle of a zoom, pressing another
         # button works to "cancel"
-        if self._ids_zoom != []:
+        if self._ids_zoom:
             self._cancel_action()
 
         if event.button == 1:
@@ -940,7 +898,7 @@ class ToolZoom(ZoomPanBase):
                 self._cancel_action()
                 return
 
-            # detect twinx,y axes and avoid double zooming
+            # detect twinx, twiny axes and avoid double zooming
             twinx, twiny = False, False
             if last_a:
                 for la in last_a:
@@ -966,9 +924,9 @@ class ToolZoom(ZoomPanBase):
 
 
 class ToolPan(ZoomPanBase):
-    """Pan axes with left mouse, zoom with right"""
+    """Pan axes with left mouse, zoom with right."""
 
-    default_keymap = rcParams['keymap.pan']
+    default_keymap = mpl.rcParams['keymap.pan']
     description = 'Pan axes with left mouse, zoom with right'
     image = 'move'
     cursor = cursors.MOVE
@@ -976,14 +934,14 @@ class ToolPan(ZoomPanBase):
 
     def __init__(self, *args):
         ZoomPanBase.__init__(self, *args)
-        self._idDrag = None
+        self._id_drag = None
 
     def _cancel_action(self):
         self._button_pressed = None
         self._xypress = []
-        self.figure.canvas.mpl_disconnect(self._idDrag)
+        self.figure.canvas.mpl_disconnect(self._id_drag)
         self.toolmanager.messagelock.release(self)
-        self.toolmanager.get_tool(_views_positions).refresh_locators()
+        self.toolmanager.get_tool(_views_positions)._refresh_locators()
 
     def _press(self, event):
         if event.button == 1:
@@ -1003,7 +961,7 @@ class ToolPan(ZoomPanBase):
                 a.start_pan(x, y, event.button)
                 self._xypress.append((a, i))
                 self.toolmanager.messagelock(self)
-                self._idDrag = self.figure.canvas.mpl_connect(
+                self._id_drag = self.figure.canvas.mpl_connect(
                     'motion_notify_event', self._mouse_move)
 
     def _release(self, event):
@@ -1011,7 +969,7 @@ class ToolPan(ZoomPanBase):
             self._cancel_action()
             return
 
-        self.figure.canvas.mpl_disconnect(self._idDrag)
+        self.figure.canvas.mpl_disconnect(self._id_drag)
         self.toolmanager.messagelock.release(self)
 
         for a, _ind in self._xypress:
@@ -1033,8 +991,8 @@ class ToolPan(ZoomPanBase):
 
 class ToolHelpBase(ToolBase):
     description = 'Print tool list, shortcuts and description'
-    default_keymap = rcParams['keymap.help']
-    image = 'help.png'
+    default_keymap = mpl.rcParams['keymap.help']
+    image = 'help'
 
     @staticmethod
     def format_shortcut(key_sequence):
@@ -1050,13 +1008,9 @@ class ToolHelpBase(ToolBase):
         return ", ".join(self.format_shortcut(keymap) for keymap in keymaps)
 
     def _get_help_entries(self):
-        entries = []
-        for name, tool in sorted(self.toolmanager.tools.items()):
-            if not tool.description:
-                continue
-            entries.append((name, self._format_tool_keymap(name),
-                            tool.description))
-        return entries
+        return [(name, self._format_tool_keymap(name), tool.description)
+                for name, tool in sorted(self.toolmanager.tools.items())
+                if tool.description]
 
     def _get_help_text(self):
         entries = self._get_help_entries()
@@ -1074,10 +1028,10 @@ class ToolHelpBase(ToolBase):
 
 
 class ToolCopyToClipboardBase(ToolBase):
-    """Tool to copy the figure to the clipboard"""
+    """Tool to copy the figure to the clipboard."""
 
     description = 'Copy the canvas figure to clipboard'
-    default_keymap = rcParams['keymap.copy']
+    default_keymap = mpl.rcParams['keymap.copy']
 
     def trigger(self, *args, **kwargs):
         message = "Copy tool is not available"
@@ -1093,8 +1047,8 @@ default_tools = {'home': ToolHome, 'back': ToolBack, 'forward': ToolForward,
                  'fullscreen': ToolFullScreen,
                  'quit': ToolQuit,
                  'quit_all': ToolQuitAll,
-                 'allnav': ToolEnableAllNavigation,
-                 'nav': ToolEnableNavigation,
+                 'allnav': _ToolEnableAllNavigation,
+                 'nav': _ToolEnableNavigation,
                  'xscale': ToolXScale,
                  'yscale': ToolYScale,
                  'position': ToolCursorPosition,
@@ -1114,12 +1068,12 @@ default_toolbar_tools = [['navigation', ['home', 'back', 'forward']],
 
 def add_tools_to_manager(toolmanager, tools=default_tools):
     """
-    Add multiple tools to `ToolManager`
+    Add multiple tools to a `.ToolManager`.
 
     Parameters
     ----------
-    toolmanager : ToolManager
-        `backend_managers.ToolManager` object that will get the tools added
+    toolmanager : `.backend_managers.ToolManager`
+        Manager to which the tools are added.
     tools : {str: class_like}, optional
         The tools to add in a {name: tool} dict, see `add_tool` for more
         info.
@@ -1136,11 +1090,10 @@ def add_tools_to_container(container, tools=default_toolbar_tools):
     Parameters
     ----------
     container : Container
-        `backend_bases.ToolContainerBase` object that will get the tools added
+        `backend_bases.ToolContainerBase` object that will get the tools added.
     tools : list, optional
-        List in the form
-        [[group1, [tool1, tool2 ...]], [group2, [...]]]
-        Where the tools given by tool1, and tool2 will display in group1.
+        List in the form ``[[group1, [tool1, tool2 ...]], [group2, [...]]]``
+        where the tools ``[tool1, tool2, ...]`` will display in group1.
         See `add_tool` for details.
     """
 
