@@ -33,7 +33,8 @@ OTHER DEALINGS IN THE SOFTWARE.
 """
 
 # History:
-# 1.0.10: added float validator (disable "Ok" and "Apply" button when not valid)
+# 1.0.10: added float validator
+#         (disable "Ok" and "Apply" button when not valid)
 # 1.0.7: added support for "Apply" button
 # 1.0.6: code cleaning
 
@@ -116,8 +117,8 @@ class ColorLayout(QtWidgets.QHBoxLayout):
 
     def update_color(self):
         color = self.text()
-        qcolor = to_qcolor(color)
-        self.colorbtn.color = qcolor  # defaults to black if not qcolor.isValid()
+        qcolor = to_qcolor(color)  # defaults to black if not qcolor.isValid()
+        self.colorbtn.color = qcolor
 
     def update_text(self, color):
         self.lineedit.setText(mcolors.to_hex(color.getRgbF(), keep_alpha=True))
@@ -217,7 +218,7 @@ class FormWidget(QtWidgets.QWidget):
             The data to be edited in the form.
         comment : str, optional
 
-        with_margin : bool, optional, default: False
+        with_margin : bool, default: False
             If False, the form elements reach to the border of the widget.
             This is the desired behavior if the FormWidget is used as a widget
             alongside with other widgets such as a QComboBox, which also do
@@ -297,7 +298,7 @@ class FormWidget(QtWidgets.QWidget):
                     field.setCheckState(QtCore.Qt.Unchecked)
             elif isinstance(value, Integral):
                 field = QtWidgets.QSpinBox(self)
-                field.setRange(-1e9, 1e9)
+                field.setRange(-10**9, 10**9)
                 field.setValue(value)
             elif isinstance(value, Real):
                 field = QtWidgets.QLineEdit(repr(value), self)
@@ -490,8 +491,8 @@ def fedit(data, title="", comment="", icon=None, parent=None, apply=None):
     (if Cancel button is pressed, return None)
 
     data: datalist, datagroup
-    title: string
-    comment: string
+    title: str
+    comment: str
     icon: QIcon instance
     parent: parent QWidget
     apply: apply callback (function)
@@ -506,8 +507,8 @@ def fedit(data, title="", comment="", icon=None, parent=None, apply=None):
 
     Supported types for field_value:
       - int, float, str, unicode, bool
-      - colors: in Qt-compatible text form, i.e. in hex format or name (red,...)
-                (automatically detected from a string)
+      - colors: in Qt-compatible text form, i.e. in hex format or name
+                (red, ...) (automatically detected from a string)
       - list/tuple:
           * the first element will be the selected index (or value)
           * the other elements can be couples (key, value) or only values
@@ -565,4 +566,4 @@ if __name__ == "__main__":
     print("result:", fedit(((datagroup, "Title 1", "Tab 1 comment"),
                             (datalist, "Title 2", "Tab 2 comment"),
                             (datalist, "Title 3", "Tab 3 comment")),
-                            "Global title"))
+                           "Global title"))
