@@ -1,9 +1,8 @@
 import builtins
+import os
 import subprocess
 import sys
-
-import matplotlib
-from matplotlib.cbook import dedent
+import textwrap
 
 
 def test_simple():
@@ -36,22 +35,19 @@ def test_override_builtins():
 
 
 def test_lazy_imports():
-    source = dedent("""
+    source = textwrap.dedent("""
     import sys
 
     import matplotlib.figure
     import matplotlib.backend_bases
     import matplotlib.pyplot
 
-    assert 'matplotlib._png' not in sys.modules
     assert 'matplotlib._tri' not in sys.modules
     assert 'matplotlib._qhull' not in sys.modules
     assert 'matplotlib._contour' not in sys.modules
     assert 'urllib.request' not in sys.modules
     """)
 
-    subprocess.check_call([
-        sys.executable,
-        '-c',
-        source
-    ])
+    subprocess.check_call(
+        [sys.executable, '-c', source],
+        env={**os.environ, "MPLBACKEND": "", "MATPLOTLIBRC": os.devnull})
