@@ -21,14 +21,14 @@ from matplotlib.testing.decorators import image_comparison
     (2, [1, 0]),
     (1, [0]),
 ])
-def test_makeMappingArray(N, result):
+def test_create_lookup_table(N, result):
     data = [(0.0, 1.0, 1.0), (0.5, 0.2, 0.2), (1.0, 0.0, 0.0)]
-    assert_array_almost_equal(mcolors.makeMappingArray(N, data), result)
+    assert_array_almost_equal(mcolors._create_lookup_table(N, data), result)
 
 
 def test_resample():
     """
-    Github issue #6025 pointed to incorrect ListedColormap._resample;
+    GitHub issue #6025 pointed to incorrect ListedColormap._resample;
     here we test the method for LinearSegmentedColormap as well.
     """
     n = 101
@@ -39,6 +39,11 @@ def test_resample():
     colorlist[:, 3] = 0.7
     lsc = mcolors.LinearSegmentedColormap.from_list('lsc', colorlist)
     lc = mcolors.ListedColormap(colorlist)
+    # Set some bad values for testing too
+    for cmap in [lsc, lc]:
+        cmap.set_under('r')
+        cmap.set_over('g')
+        cmap.set_bad('b')
     lsc3 = lsc._resample(3)
     lc3 = lc._resample(3)
     expected = np.array([[0.0, 0.2, 1.0, 0.7],
@@ -46,6 +51,58 @@ def test_resample():
                          [1.0, 0.2, 0.0, 0.7]], float)
     assert_array_almost_equal(lsc3([0, 0.5, 1]), expected)
     assert_array_almost_equal(lc3([0, 0.5, 1]), expected)
+    # Test over/under was copied properly
+    assert_array_almost_equal(lsc(np.inf), lsc3(np.inf))
+    assert_array_almost_equal(lsc(-np.inf), lsc3(-np.inf))
+    assert_array_almost_equal(lsc(np.nan), lsc3(np.nan))
+    assert_array_almost_equal(lc(np.inf), lc3(np.inf))
+    assert_array_almost_equal(lc(-np.inf), lc3(-np.inf))
+    assert_array_almost_equal(lc(np.nan), lc3(np.nan))
+
+
+def test_register_cmap():
+    new_cm = copy.copy(plt.cm.viridis)
+    cm.register_cmap('viridis2', new_cm)
+    assert plt.get_cmap('viridis2') == new_cm
+
+    with pytest.raises(ValueError,
+                       match='Arguments must include a name or a Colormap'):
+        cm.register_cmap()
+
+
+def test_colormap_global_set_warn():
+    new_cm = plt.get_cmap('viridis')
+    # Store the old value so we don't override the state later on.
+    orig_cmap = copy.copy(new_cm)
+    with pytest.warns(cbook.MatplotlibDeprecationWarning,
+                      match="You are modifying the state of a globally"):
+        # This should warn now because we've modified the global state
+        new_cm.set_under('k')
+
+    # This shouldn't warn because it is a copy
+    copy.copy(new_cm).set_under('b')
+
+    # Test that registering and then modifying warns
+    plt.register_cmap(name='test_cm', cmap=copy.copy(orig_cmap))
+    new_cm = plt.get_cmap('test_cm')
+    with pytest.warns(cbook.MatplotlibDeprecationWarning,
+                      match="You are modifying the state of a globally"):
+        # This should warn now because we've modified the global state
+        new_cm.set_under('k')
+
+    # Re-register the original
+    plt.register_cmap(cmap=orig_cmap)
+
+
+def test_colormap_dict_deprecate():
+    # Make sure we warn on get and set access into cmap_d
+    with pytest.warns(cbook.MatplotlibDeprecationWarning,
+                      match="The global colormaps dictionary is no longer"):
+        cm = plt.cm.cmap_d['viridis']
+
+    with pytest.warns(cbook.MatplotlibDeprecationWarning,
+                      match="The global colormaps dictionary is no longer"):
+        plt.cm.cmap_d['test'] = cm
 
 
 def test_colormap_copy():
@@ -62,7 +119,7 @@ def test_colormap_copy():
 
 def test_colormap_endian():
     """
-    Github issue #1005: a bug in putmask caused erroneous
+    GitHub issue #1005: a bug in putmask caused erroneous
     mapping of 1.0 when input from a non-native-byteorder
     array.
     """
@@ -75,9 +132,63 @@ def test_colormap_endian():
         assert_array_equal(cmap(anative), cmap(aforeign))
 
 
+def test_colormap_invalid():
+    """
+    GitHub issue #9892: Handling of nan's were getting mapped to under
+    rather than bad. This tests to make sure all invalid values
+    (-inf, nan, inf) are mapped respectively to (under, bad, over).
+    """
+    cmap = cm.get_cmap("plasma")
+    x = np.array([-np.inf, -1, 0, np.nan, .7, 2, np.inf])
+
+    expected = np.array([[0.050383, 0.029803, 0.527975, 1.],
+                         [0.050383, 0.029803, 0.527975, 1.],
+                         [0.050383, 0.029803, 0.527975, 1.],
+                         [0.,       0.,       0.,       0.],
+                         [0.949217, 0.517763, 0.295662, 1.],
+                         [0.940015, 0.975158, 0.131326, 1.],
+                         [0.940015, 0.975158, 0.131326, 1.]])
+    assert_array_equal(cmap(x), expected)
+
+    # Test masked representation (-inf, inf) are now masked
+    expected = np.array([[0.,       0.,       0.,       0.],
+                         [0.050383, 0.029803, 0.527975, 1.],
+                         [0.050383, 0.029803, 0.527975, 1.],
+                         [0.,       0.,       0.,       0.],
+                         [0.949217, 0.517763, 0.295662, 1.],
+                         [0.940015, 0.975158, 0.131326, 1.],
+                         [0.,       0.,       0.,       0.]])
+    assert_array_equal(cmap(np.ma.masked_invalid(x)), expected)
+
+    # Test scalar representations
+    assert_array_equal(cmap(-np.inf), cmap(0))
+    assert_array_equal(cmap(np.inf), cmap(1.0))
+    assert_array_equal(cmap(np.nan), np.array([0., 0., 0., 0.]))
+
+
+def test_colormap_return_types():
+    """
+    Make sure that tuples are returned for scalar input and
+    that the proper shapes are returned for ndarrays.
+    """
+    cmap = cm.get_cmap("plasma")
+    # Test return types and shapes
+    # scalar input needs to return a tuple of length 4
+    assert isinstance(cmap(0.5), tuple)
+    assert len(cmap(0.5)) == 4
+
+    # input array returns an ndarray of shape x.shape + (4,)
+    x = np.ones(4)
+    assert cmap(x).shape == x.shape + (4,)
+
+    # multi-dimensional array input
+    x2d = np.zeros((2, 2))
+    assert cmap(x2d).shape == x2d.shape + (4,)
+
+
 def test_BoundaryNorm():
     """
-    Github issue #1258: interpolation was failing with numpy
+    GitHub issue #1258: interpolation was failing with numpy
     1.7 pre-release.
     """
 
@@ -154,6 +265,94 @@ def test_BoundaryNorm():
     vals = np.ma.masked_invalid([np.Inf])
     assert np.all(bn(vals).mask)
 
+    # Incompatible extend and clip
+    with pytest.raises(ValueError, match="not compatible"):
+        mcolors.BoundaryNorm(np.arange(4), 5, extend='both', clip=True)
+
+    # Too small ncolors argument
+    with pytest.raises(ValueError, match="ncolors must equal or exceed"):
+        mcolors.BoundaryNorm(np.arange(4), 2)
+
+    with pytest.raises(ValueError, match="ncolors must equal or exceed"):
+        mcolors.BoundaryNorm(np.arange(4), 3, extend='min')
+
+    with pytest.raises(ValueError, match="ncolors must equal or exceed"):
+        mcolors.BoundaryNorm(np.arange(4), 4, extend='both')
+
+    # Testing extend keyword, with interpolation (large cmap)
+    bounds = [1, 2, 3]
+    cmap = cm.get_cmap('viridis')
+    mynorm = mcolors.BoundaryNorm(bounds, cmap.N, extend='both')
+    refnorm = mcolors.BoundaryNorm([0] + bounds + [4], cmap.N)
+    x = np.random.randn(100) * 10 + 2
+    ref = refnorm(x)
+    ref[ref == 0] = -1
+    ref[ref == cmap.N - 1] = cmap.N
+    assert_array_equal(mynorm(x), ref)
+
+    # Without interpolation
+    cmref = mcolors.ListedColormap(['blue', 'red'])
+    cmref.set_over('black')
+    cmref.set_under('white')
+    cmshould = mcolors.ListedColormap(['white', 'blue', 'red', 'black'])
+
+    refnorm = mcolors.BoundaryNorm(bounds, cmref.N)
+    mynorm = mcolors.BoundaryNorm(bounds, cmshould.N, extend='both')
+    assert mynorm.vmin == refnorm.vmin
+    assert mynorm.vmax == refnorm.vmax
+
+    assert mynorm(bounds[0] - 0.1) == -1  # under
+    assert mynorm(bounds[0] + 0.1) == 1   # first bin -> second color
+    assert mynorm(bounds[-1] - 0.1) == cmshould.N - 2  # next-to-last color
+    assert mynorm(bounds[-1] + 0.1) == cmshould.N  # over
+
+    x = [-1, 1.2, 2.3, 9.6]
+    assert_array_equal(cmshould(mynorm(x)), cmshould([0, 1, 2, 3]))
+    x = np.random.randn(100) * 10 + 2
+    assert_array_equal(cmshould(mynorm(x)), cmref(refnorm(x)))
+
+    # Just min
+    cmref = mcolors.ListedColormap(['blue', 'red'])
+    cmref.set_under('white')
+    cmshould = mcolors.ListedColormap(['white', 'blue', 'red'])
+
+    assert cmref.N == 2
+    assert cmshould.N == 3
+    refnorm = mcolors.BoundaryNorm(bounds, cmref.N)
+    mynorm = mcolors.BoundaryNorm(bounds, cmshould.N, extend='min')
+    assert mynorm.vmin == refnorm.vmin
+    assert mynorm.vmax == refnorm.vmax
+    x = [-1, 1.2, 2.3]
+    assert_array_equal(cmshould(mynorm(x)), cmshould([0, 1, 2]))
+    x = np.random.randn(100) * 10 + 2
+    assert_array_equal(cmshould(mynorm(x)), cmref(refnorm(x)))
+
+    # Just max
+    cmref = mcolors.ListedColormap(['blue', 'red'])
+    cmref.set_over('black')
+    cmshould = mcolors.ListedColormap(['blue', 'red', 'black'])
+
+    assert cmref.N == 2
+    assert cmshould.N == 3
+    refnorm = mcolors.BoundaryNorm(bounds, cmref.N)
+    mynorm = mcolors.BoundaryNorm(bounds, cmshould.N, extend='max')
+    assert mynorm.vmin == refnorm.vmin
+    assert mynorm.vmax == refnorm.vmax
+    x = [1.2, 2.3, 4]
+    assert_array_equal(cmshould(mynorm(x)), cmshould([0, 1, 2]))
+    x = np.random.randn(100) * 10 + 2
+    assert_array_equal(cmshould(mynorm(x)), cmref(refnorm(x)))
+
+
+@pytest.mark.parametrize("vmin,vmax", [[-1, 2], [3, 1]])
+def test_lognorm_invalid(vmin, vmax):
+    # Check that invalid limits in LogNorm error
+    norm = mcolors.LogNorm(vmin=vmin, vmax=vmax)
+    with pytest.raises(ValueError):
+        norm(1)
+    with pytest.raises(ValueError):
+        norm.inverse(1)
+
 
 def test_LogNorm():
     """
@@ -231,92 +430,91 @@ def test_Normalize():
     assert 0 < norm(1 + 50 * eps) < 1
 
 
-def test_DivergingNorm_autoscale():
-    norm = mcolors.DivergingNorm(vcenter=20)
+def test_TwoSlopeNorm_autoscale():
+    norm = mcolors.TwoSlopeNorm(vcenter=20)
     norm.autoscale([10, 20, 30, 40])
     assert norm.vmin == 10.
     assert norm.vmax == 40.
 
 
-def test_DivergingNorm_autoscale_None_vmin():
-    norm = mcolors.DivergingNorm(2, vmin=0, vmax=None)
+def test_TwoSlopeNorm_autoscale_None_vmin():
+    norm = mcolors.TwoSlopeNorm(2, vmin=0, vmax=None)
     norm.autoscale_None([1, 2, 3, 4, 5])
     assert norm(5) == 1
     assert norm.vmax == 5
 
 
-def test_DivergingNorm_autoscale_None_vmax():
-    norm = mcolors.DivergingNorm(2, vmin=None, vmax=10)
+def test_TwoSlopeNorm_autoscale_None_vmax():
+    norm = mcolors.TwoSlopeNorm(2, vmin=None, vmax=10)
     norm.autoscale_None([1, 2, 3, 4, 5])
     assert norm(1) == 0
     assert norm.vmin == 1
 
 
-def test_DivergingNorm_scale():
-    norm = mcolors.DivergingNorm(2)
+def test_TwoSlopeNorm_scale():
+    norm = mcolors.TwoSlopeNorm(2)
     assert norm.scaled() is False
     norm([1, 2, 3, 4])
     assert norm.scaled() is True
 
 
-def test_DivergingNorm_scaleout_center():
+def test_TwoSlopeNorm_scaleout_center():
     # test the vmin never goes above vcenter
-    norm = mcolors.DivergingNorm(vcenter=0)
-    x = norm([1, 2, 3, 5])
+    norm = mcolors.TwoSlopeNorm(vcenter=0)
+    norm([1, 2, 3, 5])
     assert norm.vmin == 0
     assert norm.vmax == 5
 
 
-def test_DivergingNorm_scaleout_center_max():
+def test_TwoSlopeNorm_scaleout_center_max():
     # test the vmax never goes below vcenter
-    norm = mcolors.DivergingNorm(vcenter=0)
-    x = norm([-1, -2, -3, -5])
+    norm = mcolors.TwoSlopeNorm(vcenter=0)
+    norm([-1, -2, -3, -5])
     assert norm.vmax == 0
     assert norm.vmin == -5
 
 
-def test_DivergingNorm_Even():
-    norm = mcolors.DivergingNorm(vmin=-1, vcenter=0, vmax=4)
+def test_TwoSlopeNorm_Even():
+    norm = mcolors.TwoSlopeNorm(vmin=-1, vcenter=0, vmax=4)
     vals = np.array([-1.0, -0.5, 0.0, 1.0, 2.0, 3.0, 4.0])
     expected = np.array([0.0, 0.25, 0.5, 0.625, 0.75, 0.875, 1.0])
     assert_array_equal(norm(vals), expected)
 
 
-def test_DivergingNorm_Odd():
-    norm = mcolors.DivergingNorm(vmin=-2, vcenter=0, vmax=5)
+def test_TwoSlopeNorm_Odd():
+    norm = mcolors.TwoSlopeNorm(vmin=-2, vcenter=0, vmax=5)
     vals = np.array([-2.0, -1.0, 0.0, 1.0, 2.0, 3.0, 4.0, 5.0])
     expected = np.array([0.0, 0.25, 0.5, 0.6, 0.7, 0.8, 0.9, 1.0])
     assert_array_equal(norm(vals), expected)
 
 
-def test_DivergingNorm_VminEqualsVcenter():
+def test_TwoSlopeNorm_VminEqualsVcenter():
     with pytest.raises(ValueError):
-        norm = mcolors.DivergingNorm(vmin=-2, vcenter=-2, vmax=2)
+        mcolors.TwoSlopeNorm(vmin=-2, vcenter=-2, vmax=2)
 
 
-def test_DivergingNorm_VmaxEqualsVcenter():
+def test_TwoSlopeNorm_VmaxEqualsVcenter():
     with pytest.raises(ValueError):
-        norm = mcolors.DivergingNorm(vmin=-2, vcenter=2, vmax=2)
+        mcolors.TwoSlopeNorm(vmin=-2, vcenter=2, vmax=2)
 
 
-def test_DivergingNorm_VminGTVcenter():
+def test_TwoSlopeNorm_VminGTVcenter():
     with pytest.raises(ValueError):
-        norm = mcolors.DivergingNorm(vmin=10, vcenter=0, vmax=20)
+        mcolors.TwoSlopeNorm(vmin=10, vcenter=0, vmax=20)
 
 
-def test_DivergingNorm_DivergingNorm_VminGTVmax():
+def test_TwoSlopeNorm_TwoSlopeNorm_VminGTVmax():
     with pytest.raises(ValueError):
-        norm = mcolors.DivergingNorm(vmin=10, vcenter=0, vmax=5)
+        mcolors.TwoSlopeNorm(vmin=10, vcenter=0, vmax=5)
 
 
-def test_DivergingNorm_VcenterGTVmax():
-    vals = np.arange(50)
+def test_TwoSlopeNorm_VcenterGTVmax():
     with pytest.raises(ValueError):
-        norm = mcolors.DivergingNorm(vmin=10, vcenter=25, vmax=20)
+        mcolors.TwoSlopeNorm(vmin=10, vcenter=25, vmax=20)
 
 
-def test_DivergingNorm_premature_scaling():
-    norm = mcolors.DivergingNorm(vcenter=2)
+def test_TwoSlopeNorm_premature_scaling():
+    norm = mcolors.TwoSlopeNorm(vcenter=2)
     with pytest.raises(ValueError):
         norm.inverse(np.array([0.1, 0.5, 0.9]))
 
@@ -325,7 +523,7 @@ def test_SymLogNorm():
     """
     Test SymLogNorm behavior
     """
-    norm = mcolors.SymLogNorm(3, vmax=5, linscale=1.2)
+    norm = mcolors.SymLogNorm(3, vmax=5, linscale=1.2, base=np.e)
     vals = np.array([-30, -1, 2, 6], dtype=float)
     normed_vals = norm(vals)
     expected = [0., 0.53980074, 0.826991, 1.02758204]
@@ -335,18 +533,32 @@ def test_SymLogNorm():
     _mask_tester(norm, vals)
 
     # Ensure that specifying vmin returns the same result as above
-    norm = mcolors.SymLogNorm(3, vmin=-30, vmax=5, linscale=1.2)
+    norm = mcolors.SymLogNorm(3, vmin=-30, vmax=5, linscale=1.2, base=np.e)
     normed_vals = norm(vals)
     assert_array_almost_equal(normed_vals, expected)
 
+    # test something more easily checked.
+    norm = mcolors.SymLogNorm(1, vmin=-np.e**3, vmax=np.e**3, base=np.e)
+    nn = norm([-np.e**3, -np.e**2, -np.e**1, -1,
+              0, 1, np.e**1, np.e**2, np.e**3])
+    xx = np.array([0., 0.109123, 0.218246, 0.32737, 0.5, 0.67263,
+                   0.781754, 0.890877, 1.])
+    assert_array_almost_equal(nn, xx)
+    norm = mcolors.SymLogNorm(1, vmin=-10**3, vmax=10**3, base=10)
+    nn = norm([-10**3, -10**2, -10**1, -1,
+              0, 1, 10**1, 10**2, 10**3])
+    xx = np.array([0., 0.121622, 0.243243, 0.364865, 0.5, 0.635135,
+                   0.756757, 0.878378, 1.])
+    assert_array_almost_equal(nn, xx)
+
 
 def test_SymLogNorm_colorbar():
     """
     Test un-called SymLogNorm in a colorbar.
     """
-    norm = mcolors.SymLogNorm(0.1, vmin=-1, vmax=1, linscale=1)
+    norm = mcolors.SymLogNorm(0.1, vmin=-1, vmax=1, linscale=1, base=np.e)
     fig = plt.figure()
-    cbar = mcolorbar.ColorbarBase(fig.add_subplot(111), norm=norm)
+    mcolorbar.ColorbarBase(fig.add_subplot(111), norm=norm)
     plt.close(fig)
 
 
@@ -355,7 +567,7 @@ def test_SymLogNorm_single_zero():
     Test SymLogNorm to ensure it is not adding sub-ticks to zero label
     """
     fig = plt.figure()
-    norm = mcolors.SymLogNorm(1e-5, vmin=-1, vmax=1)
+    norm = mcolors.SymLogNorm(1e-5, vmin=-1, vmax=1, base=np.e)
     cbar = mcolorbar.ColorbarBase(fig.add_subplot(111), norm=norm)
     ticks = cbar.get_ticks()
     assert sum(ticks == 0) == 1
@@ -387,8 +599,7 @@ def _mask_tester(norm_instance, vals):
     assert_array_equal(masked_array.mask, norm_instance(masked_array).mask)
 
 
-@image_comparison(baseline_images=['levels_and_colors'],
-                  extensions=['png'])
+@image_comparison(['levels_and_colors.png'])
 def test_cmap_and_norm_from_levels_and_colors():
     data = np.linspace(-2, 4, 49).reshape(7, 7)
     levels = [-1, 2, 2.5, 3]
@@ -404,6 +615,35 @@ def test_cmap_and_norm_from_levels_and_colors():
     ax.tick_params(labelleft=False, labelbottom=False)
 
 
+@image_comparison(baseline_images=['boundarynorm_and_colorbar'],
+                  extensions=['png'])
+def test_boundarynorm_and_colorbarbase():
+
+    # Make a figure and axes with dimensions as desired.
+    fig = plt.figure()
+    ax1 = fig.add_axes([0.05, 0.80, 0.9, 0.15])
+    ax2 = fig.add_axes([0.05, 0.475, 0.9, 0.15])
+    ax3 = fig.add_axes([0.05, 0.15, 0.9, 0.15])
+
+    # Set the colormap and bounds
+    bounds = [-1, 2, 5, 7, 12, 15]
+    cmap = cm.get_cmap('viridis')
+
+    # Default behavior
+    norm = mcolors.BoundaryNorm(bounds, cmap.N)
+    cb1 = mcolorbar.ColorbarBase(ax1, cmap=cmap, norm=norm, extend='both',
+                                 orientation='horizontal')
+    # New behavior
+    norm = mcolors.BoundaryNorm(bounds, cmap.N, extend='both')
+    cb2 = mcolorbar.ColorbarBase(ax2, cmap=cmap, norm=norm,
+                                 orientation='horizontal')
+
+    # User can still force to any extend='' if really needed
+    norm = mcolors.BoundaryNorm(bounds, cmap.N, extend='both')
+    cb3 = mcolorbar.ColorbarBase(ax3, cmap=cmap, norm=norm,
+                                 extend='neither', orientation='horizontal')
+
+
 def test_cmap_and_norm_from_levels_and_colors2():
     levels = [-1, 2, 2.5, 3]
     colors = ['red', (0, 1, 0), 'blue', (0.5, 0.5, 0.5), (0.0, 0.0, 0.0, 1.0)]
@@ -468,10 +708,10 @@ def test_rgb_hsv_round_trip():
     for a_shape in [(500, 500, 3), (500, 3), (1, 3), (3,)]:
         np.random.seed(0)
         tt = np.random.random(a_shape)
-        assert_array_almost_equal(tt,
-            mcolors.hsv_to_rgb(mcolors.rgb_to_hsv(tt)))
-        assert_array_almost_equal(tt,
-            mcolors.rgb_to_hsv(mcolors.hsv_to_rgb(tt)))
+        assert_array_almost_equal(
+            tt, mcolors.hsv_to_rgb(mcolors.rgb_to_hsv(tt)))
+        assert_array_almost_equal(
+            tt, mcolors.rgb_to_hsv(mcolors.hsv_to_rgb(tt)))
 
 
 def test_autoscale_masked():
@@ -481,30 +721,22 @@ def test_autoscale_masked():
     plt.draw()
 
 
-def test_colors_no_float():
-    # Gray must be a string to distinguish 3-4 grays from RGB or RGBA.
-    with pytest.raises(ValueError):
-        mcolors.to_rgba(0.4)
-
-
-@image_comparison(baseline_images=['light_source_shading_topo'],
-                  extensions=['png'])
+@image_comparison(['light_source_shading_topo.png'])
 def test_light_source_topo_surface():
     """Shades a DEM using different v.e.'s and blend modes."""
-    with cbook.get_sample_data('jacksboro_fault_dem.npz') as file, \
-         np.load(file) as dem:
-        elev = dem['elevation']
-        dx, dy = dem['dx'], dem['dy']
-        # Get the true cellsize in meters for accurate vertical exaggeration
-        # Convert from decimal degrees to meters
-        dx = 111320.0 * dx * np.cos(dem['ymin'])
-        dy = 111320.0 * dy
+    dem = cbook.get_sample_data('jacksboro_fault_dem.npz', np_load=True)
+    elev = dem['elevation']
+    dx, dy = dem['dx'], dem['dy']
+    # Get the true cellsize in meters for accurate vertical exaggeration
+    # Convert from decimal degrees to meters
+    dx = 111320.0 * dx * np.cos(dem['ymin'])
+    dy = 111320.0 * dy
 
     ls = mcolors.LightSource(315, 45)
     cmap = cm.gist_earth
 
-    fig, axes = plt.subplots(nrows=3, ncols=3)
-    for row, mode in zip(axes, ['hsv', 'overlay', 'soft']):
+    fig, axs = plt.subplots(nrows=3, ncols=3)
+    for row, mode in zip(axs, ['hsv', 'overlay', 'soft']):
         for ax, ve in zip(row, [0.1, 1, 10]):
             rgb = ls.shade(elev, cmap, vert_exag=ve, dx=dx, dy=dy,
                            blend_mode=mode)
@@ -513,8 +745,10 @@ def test_light_source_topo_surface():
 
 
 def test_light_source_shading_default():
-    """Array comparison test for the default "hsv" blend mode. Ensure the
-    default result doesn't change without warning."""
+    """
+    Array comparison test for the default "hsv" blend mode. Ensure the
+    default result doesn't change without warning.
+    """
     y, x = np.mgrid[-1.2:1.2:8j, -1.2:1.2:8j]
     z = 10 * np.cos(x**2 + y**2)
 
@@ -559,17 +793,32 @@ def test_light_source_shading_default():
           [1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00],
           [1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00],
           [1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00]]
-        ]).T
+         ]).T
 
     assert_array_almost_equal(rgb, expect, decimal=2)
 
 
+def test_light_source_shading_empty_mask():
+    y, x = np.mgrid[-1.2:1.2:8j, -1.2:1.2:8j]
+    z0 = 10 * np.cos(x**2 + y**2)
+    z1 = np.ma.array(z0)
+
+    cmap = plt.cm.copper
+    ls = mcolors.LightSource(315, 45)
+    rgb0 = ls.shade(z0, cmap)
+    rgb1 = ls.shade(z1, cmap)
+
+    assert_array_almost_equal(rgb0, rgb1)
+
+
 # Numpy 1.9.1 fixed a bug in masked arrays which resulted in
 # additional elements being masked when calculating the gradient thus
 # the output is different with earlier numpy versions.
 def test_light_source_masked_shading():
-    """Array comparison test for a surface with a masked portion. Ensures that
-    we don't wind up with "fringes" of odd colors around masked regions."""
+    """
+    Array comparison test for a surface with a masked portion. Ensures that
+    we don't wind up with "fringes" of odd colors around masked regions.
+    """
     y, x = np.mgrid[-1.2:1.2:8j, -1.2:1.2:8j]
     z = 10 * np.cos(x**2 + y**2)
 
@@ -616,14 +865,16 @@ def test_light_source_masked_shading():
           [1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00],
           [1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00],
           [1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00]],
-        ]).T
+         ]).T
 
     assert_array_almost_equal(rgb, expect, decimal=2)
 
 
 def test_light_source_hillshading():
-    """Compare the current hillshading method against one that should be
-    mathematically equivalent. Illuminates a cone from a range of angles."""
+    """
+    Compare the current hillshading method against one that should be
+    mathematically equivalent. Illuminates a cone from a range of angles.
+    """
 
     def alternative_hillshade(azimuth, elev, z):
         illum = _sph2cart(*_azimuth2math(azimuth, elev))
@@ -651,20 +902,25 @@ def test_light_source_hillshading():
 
 
 def test_light_source_planar_hillshading():
-    """Ensure that the illumination intensity is correct for planar
-    surfaces."""
+    """
+    Ensure that the illumination intensity is correct for planar surfaces.
+    """
 
     def plane(azimuth, elevation, x, y):
-        """Create a plane whose normal vector is at the given azimuth and
-        elevation."""
+        """
+        Create a plane whose normal vector is at the given azimuth and
+        elevation.
+        """
         theta, phi = _azimuth2math(azimuth, elevation)
         a, b, c = _sph2cart(theta, phi)
         z = -(a*x + b*y) / c
         return z
 
     def angled_plane(azimuth, elevation, angle, x, y):
-        """Create a plane whose normal vector is at an angle from the given
-        azimuth and elevation."""
+        """
+        Create a plane whose normal vector is at an angle from the given
+        azimuth and elevation.
+        """
         elevation = elevation + angle
         if elevation > 90:
             azimuth = (azimuth + 180) % 360
@@ -696,8 +952,10 @@ def _sph2cart(theta, phi):
 
 
 def _azimuth2math(azimuth, elevation):
-    """Converts from clockwise-from-north and up-from-horizontal to
-    mathematical conventions."""
+    """
+    Convert from clockwise-from-north and up-from-horizontal to mathematical
+    conventions.
+    """
     theta = np.radians((90 - azimuth) % 360)
     phi = np.radians(90 - elevation)
     return theta, phi
@@ -714,16 +972,22 @@ def test_pandas_iterable(pd):
     assert_array_equal(cm1.colors, cm2.colors)
 
 
-@pytest.mark.parametrize('name', sorted(cm.cmap_d))
+@pytest.mark.parametrize('name', sorted(plt.colormaps()))
 def test_colormap_reversing(name):
-    """Check the generated _lut data of a colormap and corresponding
-    reversed colormap if they are almost the same."""
+    """
+    Check the generated _lut data of a colormap and corresponding reversed
+    colormap if they are almost the same.
+    """
     cmap = plt.get_cmap(name)
     cmap_r = cmap.reversed()
     if not cmap_r._isinit:
         cmap._init()
         cmap_r._init()
     assert_array_almost_equal(cmap._lut[:-3], cmap_r._lut[-4::-1])
+    # Test the bad, over, under values too
+    assert_array_almost_equal(cmap(-np.inf), cmap_r(np.inf))
+    assert_array_almost_equal(cmap(np.inf), cmap_r(-np.inf))
+    assert_array_almost_equal(cmap(np.nan), cmap_r(np.nan))
 
 
 def test_cn():
@@ -751,6 +1015,7 @@ def test_cn():
 def test_conversions():
     # to_rgba_array("none") returns a (0, 4) array.
     assert_array_equal(mcolors.to_rgba_array("none"), np.zeros((0, 4)))
+    assert_array_equal(mcolors.to_rgba_array([]), np.zeros((0, 4)))
     # a list of grayscale levels, not a single color.
     assert_array_equal(
         mcolors.to_rgba_array([".2", ".5", ".8"]),
@@ -781,14 +1046,32 @@ def test_to_rgba_array_single_str():
     assert_array_equal(mcolors.to_rgba_array("red"), [(1, 0, 0, 1)])
 
     # single char color sequence is deprecated
-    array = mcolors.to_rgba_array("rgb")
+    with pytest.warns(cbook.MatplotlibDeprecationWarning,
+                      match="Using a string of single character colors as a "
+                            "color sequence is deprecated"):
+        array = mcolors.to_rgba_array("rgb")
     assert_array_equal(array, [(1, 0, 0, 1), (0, 0.5, 0, 1), (0, 0, 1, 1)])
 
     with pytest.raises(ValueError,
-                       match="Invalid RGBA argument: 'x'"):
+                       match="neither a valid single color nor a color "
+                             "sequence"):
         mcolors.to_rgba_array("rgbx")
 
 
+def test_failed_conversions():
+    with pytest.raises(ValueError):
+        mcolors.to_rgba('5')
+    with pytest.raises(ValueError):
+        mcolors.to_rgba('-1')
+    with pytest.raises(ValueError):
+        mcolors.to_rgba('nan')
+    with pytest.raises(ValueError):
+        mcolors.to_rgba('unknown_color')
+    with pytest.raises(ValueError):
+        # Gray must be a string to distinguish 3-4 grays from RGB or RGBA.
+        mcolors.to_rgba(0.4)
+
+
 def test_grey_gray():
     color_mapping = mcolors._colors_full_map
     for k in color_mapping.keys():
@@ -806,7 +1089,7 @@ def test_tableau_order():
     assert list(mcolors.TABLEAU_COLORS.values()) == dflt_cycle
 
 
-def test_ndarray_subclass_norm(recwarn):
+def test_ndarray_subclass_norm():
     # Emulate an ndarray subclass that handles units
     # which objects when adding or subtracting with other
     # arrays. See #6622 and #8696
@@ -821,18 +1104,34 @@ def test_ndarray_subclass_norm(recwarn):
     mydata = data.view(MyArray)
 
     for norm in [mcolors.Normalize(), mcolors.LogNorm(),
-                 mcolors.SymLogNorm(3, vmax=5, linscale=1),
+                 mcolors.SymLogNorm(3, vmax=5, linscale=1, base=np.e),
                  mcolors.Normalize(vmin=mydata.min(), vmax=mydata.max()),
-                 mcolors.SymLogNorm(3, vmin=mydata.min(), vmax=mydata.max()),
+                 mcolors.SymLogNorm(3, vmin=mydata.min(), vmax=mydata.max(),
+                                    base=np.e),
                  mcolors.PowerNorm(1)]:
         assert_array_equal(norm(mydata), norm(data))
         fig, ax = plt.subplots()
         ax.imshow(mydata, norm=norm)
-        fig.canvas.draw()
-        assert len(recwarn) == 0
-        recwarn.clear()
+        fig.canvas.draw()  # Check that no warning is emitted.
 
 
 def test_same_color():
     assert mcolors.same_color('k', (0, 0, 0))
     assert not mcolors.same_color('w', (1, 1, 0))
+    assert mcolors.same_color(['red', 'blue'], ['r', 'b'])
+    assert mcolors.same_color('none', 'none')
+    assert not mcolors.same_color('none', 'red')
+    with pytest.raises(ValueError):
+        mcolors.same_color(['r', 'g', 'b'], ['r'])
+    with pytest.raises(ValueError):
+        mcolors.same_color(['red', 'green'], 'none')
+
+
+def test_hex_shorthand_notation():
+    assert mcolors.same_color("#123", "#112233")
+    assert mcolors.same_color("#123a", "#112233aa")
+
+
+def test_DivergingNorm_deprecated():
+    with pytest.warns(cbook.MatplotlibDeprecationWarning):
+        norm = mcolors.DivergingNorm(vcenter=0)
