@@ -2,20 +2,17 @@ from contextlib import ExitStack
 from copy import copy
 import io
 import os
-import sys
 from pathlib import Path
 import platform
+import sys
 import urllib.request
-import warnings
 
 import numpy as np
-from numpy import ma
 from numpy.testing import assert_array_equal
+from PIL import Image
 
 from matplotlib import (
-    colors, image as mimage, patches, pyplot as plt, style,
-    rc_context, rcParams)
-from matplotlib.cbook import MatplotlibDeprecationWarning
+    colors, image as mimage, patches, pyplot as plt, style, rcParams)
 from matplotlib.image import (AxesImage, BboxImage, FigureImage,
                               NonUniformImage, PcolorImage)
 from matplotlib.testing.decorators import check_figures_equal, image_comparison
@@ -24,9 +21,12 @@ from matplotlib.transforms import Bbox, Affine2D, TransformedBbox
 import pytest
 
 
-@image_comparison(baseline_images=['image_interps'], style='mpl20')
+@image_comparison(['image_interps'], style='mpl20')
 def test_image_interps():
-    'make the basic nearest, bilinear and bicubic interps'
+    """Make the basic nearest, bilinear and bicubic interps."""
+    # Remove this line when this test image is regenerated.
+    plt.rcParams['text.kerning_factor'] = 6
+
     X = np.arange(100)
     X = X.reshape(5, 20)
 
@@ -45,10 +45,9 @@ def test_image_interps():
     ax3.set_ylabel('bicubic')
 
 
-@image_comparison(baseline_images=['interp_alpha'],
-                  extensions=['png'], remove_text=True)
+@image_comparison(['interp_alpha.png'], remove_text=True)
 def test_alpha_interp():
-    'Test the interpolation of the alpha channel on RGBA images'
+    """Test the interpolation of the alpha channel on RGBA images"""
     fig, (axl, axr) = plt.subplots(1, 2)
     # full green image
     img = np.zeros((5, 5, 4))
@@ -59,10 +58,10 @@ def test_alpha_interp():
     axr.imshow(img, interpolation="bilinear")
 
 
-@image_comparison(baseline_images=['interp_nearest_vs_none'],
+@image_comparison(['interp_nearest_vs_none'],
                   extensions=['pdf', 'svg'], remove_text=True)
 def test_interp_nearest_vs_none():
-    'Test the effect of "nearest" and "none" interpolation'
+    """Test the effect of "nearest" and "none" interpolation"""
     # Setting dpi to something really small makes the difference very
     # visible. This works fine with pdf, since the dpi setting doesn't
     # affect anything but images, but the agg output becomes unusably
@@ -79,8 +78,9 @@ def test_interp_nearest_vs_none():
     ax2.set_title('interpolation nearest')
 
 
-def do_figimage(suppressComposite):
-    """Helper for the next two tests."""
+@pytest.mark.parametrize('suppressComposite', [False, True])
+@image_comparison(['figimage'], extensions=['png', 'pdf'])
+def test_figimage(suppressComposite):
     fig = plt.figure(figsize=(2, 2), dpi=100)
     fig.suppressComposite = suppressComposite
     x, y = np.ix_(np.arange(100) / 100.0, np.arange(100) / 100)
@@ -94,18 +94,6 @@ def do_figimage(suppressComposite):
     fig.figimage(img[::-1, ::-1], xo=100, yo=100, origin='lower')
 
 
-@image_comparison(baseline_images=['figimage-0'], extensions=['png', 'pdf'])
-def test_figimage0():
-    suppressComposite = False
-    do_figimage(suppressComposite)
-
-
-@image_comparison(baseline_images=['figimage-1'], extensions=['png', 'pdf'])
-def test_figimage1():
-    suppressComposite = True
-    do_figimage(suppressComposite)
-
-
 def test_image_python_io():
     fig, ax = plt.subplots()
     ax.plot([1, 2, 3])
@@ -115,22 +103,62 @@ def test_image_python_io():
     plt.imread(buffer)
 
 
+@pytest.mark.parametrize(
+    "img_size, fig_size, interpolation",
+    [(5, 2, "hanning"),  # data larger than figure.
+     (5, 5, "nearest"),  # exact resample.
+     (5, 10, "nearest"),  # double sample.
+     (3, 2.9, "hanning"),  # <3 upsample.
+     (3, 9.1, "nearest"),  # >3 upsample.
+     ])
+@check_figures_equal(extensions=['png'])
+def test_imshow_antialiased(fig_test, fig_ref,
+                            img_size, fig_size, interpolation):
+    np.random.seed(19680801)
+    dpi = plt.rcParams["savefig.dpi"]
+    A = np.random.rand(int(dpi * img_size), int(dpi * img_size))
+    for fig in [fig_test, fig_ref]:
+        fig.set_size_inches(fig_size, fig_size)
+    axs = fig_test.subplots()
+    axs.set_position([0, 0, 1, 1])
+    axs.imshow(A, interpolation='antialiased')
+    axs = fig_ref.subplots()
+    axs.set_position([0, 0, 1, 1])
+    axs.imshow(A, interpolation=interpolation)
+
+
+@check_figures_equal(extensions=['png'])
+def test_imshow_zoom(fig_test, fig_ref):
+    # should be less than 3 upsample, so should be nearest...
+    np.random.seed(19680801)
+    dpi = plt.rcParams["savefig.dpi"]
+    A = np.random.rand(int(dpi * 3), int(dpi * 3))
+    for fig in [fig_test, fig_ref]:
+        fig.set_size_inches(2.9, 2.9)
+    axs = fig_test.subplots()
+    axs.imshow(A, interpolation='antialiased')
+    axs.set_xlim([10, 20])
+    axs.set_ylim([10, 20])
+    axs = fig_ref.subplots()
+    axs.imshow(A, interpolation='nearest')
+    axs.set_xlim([10, 20])
+    axs.set_ylim([10, 20])
+
+
 @check_figures_equal()
 def test_imshow_pil(fig_test, fig_ref):
     style.use("default")
-    PIL = pytest.importorskip("PIL")
     png_path = Path(__file__).parent / "baseline_images/pngsuite/basn3p04.png"
     tiff_path = Path(__file__).parent / "baseline_images/test_image/uint16.tif"
     axs = fig_test.subplots(2)
-    axs[0].imshow(PIL.Image.open(png_path))
-    axs[1].imshow(PIL.Image.open(tiff_path))
+    axs[0].imshow(Image.open(png_path))
+    axs[1].imshow(Image.open(tiff_path))
     axs = fig_ref.subplots(2)
-    axs[0].imshow(plt.imread(str(png_path)))
+    axs[0].imshow(plt.imread(png_path))
     axs[1].imshow(plt.imread(tiff_path))
 
 
 def test_imread_pil_uint16():
-    pytest.importorskip("PIL")
     img = plt.imread(os.path.join(os.path.dirname(__file__),
                      'baseline_images', 'test_image', 'uint16.tif'))
     assert img.dtype == np.uint16
@@ -138,7 +166,6 @@ def test_imread_pil_uint16():
 
 
 def test_imread_fspath():
-    pytest.importorskip("PIL")
     img = plt.imread(
         Path(__file__).parent / 'baseline_images/test_image/uint16.tif')
     assert img.dtype == np.uint16
@@ -147,8 +174,6 @@ def test_imread_fspath():
 
 @pytest.mark.parametrize("fmt", ["png", "jpg", "jpeg", "tiff"])
 def test_imsave(fmt):
-    if fmt in ["jpg", "jpeg", "tiff"]:
-        pytest.importorskip("PIL")
     has_alpha = fmt not in ["jpg", "jpeg"]
 
     # The goal here is that the user can specify an output logical DPI
@@ -212,7 +237,28 @@ def test_imsave_color_alpha():
         assert_array_equal(data, arr_buf)
 
 
-@image_comparison(baseline_images=['image_alpha'], remove_text=True)
+def test_imsave_pil_kwargs_png():
+    from PIL.PngImagePlugin import PngInfo
+    buf = io.BytesIO()
+    pnginfo = PngInfo()
+    pnginfo.add_text("Software", "test")
+    plt.imsave(buf, [[0, 1], [2, 3]],
+               format="png", pil_kwargs={"pnginfo": pnginfo})
+    im = Image.open(buf)
+    assert im.info["Software"] == "test"
+
+
+def test_imsave_pil_kwargs_tiff():
+    from PIL.TiffTags import TAGS_V2 as TAGS
+    buf = io.BytesIO()
+    pil_kwargs = {"description": "test image"}
+    plt.imsave(buf, [[0, 1], [2, 3]], format="tiff", pil_kwargs=pil_kwargs)
+    im = Image.open(buf)
+    tags = {TAGS[k].name: v for k, v in im.tag_v2.items()}
+    assert tags["ImageDescription"] == "test image"
+
+
+@image_comparison(['image_alpha'], remove_text=True)
 def test_image_alpha():
     plt.figure()
 
@@ -236,7 +282,7 @@ def test_cursor_data():
     im = ax.imshow(np.arange(100).reshape(10, 10), origin='upper')
 
     x, y = 4, 4
-    xdisp, ydisp = ax.transData.transform_point([x, y])
+    xdisp, ydisp = ax.transData.transform([x, y])
 
     event = MouseEvent('motion_notify_event', fig.canvas, xdisp, ydisp)
     assert im.get_cursor_data(event) == 44
@@ -244,7 +290,7 @@ def test_cursor_data():
     # Now try for a point outside the image
     # Tests issue #4957
     x, y = 10.1, 4
-    xdisp, ydisp = ax.transData.transform_point([x, y])
+    xdisp, ydisp = ax.transData.transform([x, y])
 
     event = MouseEvent('motion_notify_event', fig.canvas, xdisp, ydisp)
     assert im.get_cursor_data(event) is None
@@ -252,7 +298,7 @@ def test_cursor_data():
     # Hmm, something is wrong here... I get 0, not None...
     # But, this works further down in the tests with extents flipped
     #x, y = 0.1, -0.1
-    #xdisp, ydisp = ax.transData.transform_point([x, y])
+    #xdisp, ydisp = ax.transData.transform([x, y])
     #event = MouseEvent('motion_notify_event', fig.canvas, xdisp, ydisp)
     #z = im.get_cursor_data(event)
     #assert z is None, "Did not get None, got %d" % z
@@ -262,7 +308,7 @@ def test_cursor_data():
     im = ax.imshow(np.arange(100).reshape(10, 10), origin='lower')
 
     x, y = 4, 4
-    xdisp, ydisp = ax.transData.transform_point([x, y])
+    xdisp, ydisp = ax.transData.transform([x, y])
 
     event = MouseEvent('motion_notify_event', fig.canvas, xdisp, ydisp)
     assert im.get_cursor_data(event) == 44
@@ -271,7 +317,7 @@ def test_cursor_data():
     im = ax.imshow(np.arange(100).reshape(10, 10), extent=[0, 0.5, 0, 0.5])
 
     x, y = 0.25, 0.25
-    xdisp, ydisp = ax.transData.transform_point([x, y])
+    xdisp, ydisp = ax.transData.transform([x, y])
 
     event = MouseEvent('motion_notify_event', fig.canvas, xdisp, ydisp)
     assert im.get_cursor_data(event) == 55
@@ -279,13 +325,13 @@ def test_cursor_data():
     # Now try for a point outside the image
     # Tests issue #4957
     x, y = 0.75, 0.25
-    xdisp, ydisp = ax.transData.transform_point([x, y])
+    xdisp, ydisp = ax.transData.transform([x, y])
 
     event = MouseEvent('motion_notify_event', fig.canvas, xdisp, ydisp)
     assert im.get_cursor_data(event) is None
 
     x, y = 0.01, -0.01
-    xdisp, ydisp = ax.transData.transform_point([x, y])
+    xdisp, ydisp = ax.transData.transform([x, y])
 
     event = MouseEvent('motion_notify_event', fig.canvas, xdisp, ydisp)
     assert im.get_cursor_data(event) is None
@@ -302,7 +348,7 @@ def test_format_cursor_data(data, text_without_colorbar, text_with_colorbar):
     fig, ax = plt.subplots()
     im = ax.imshow(data)
 
-    xdisp, ydisp = ax.transData.transform_point([0, 0])
+    xdisp, ydisp = ax.transData.transform([0, 0])
     event = MouseEvent('motion_notify_event', fig.canvas, xdisp, ydisp)
     assert im.get_cursor_data(event) == data[0][0]
     assert im.format_cursor_data(im.get_cursor_data(event)) \
@@ -316,7 +362,7 @@ def test_format_cursor_data(data, text_without_colorbar, text_with_colorbar):
         == text_with_colorbar
 
 
-@image_comparison(baseline_images=['image_clip'], style='mpl20')
+@image_comparison(['image_clip'], style='mpl20')
 def test_image_clip():
     d = [[1, 2], [3, 4]]
 
@@ -326,10 +372,8 @@ def test_image_clip():
     im.set_clip_path(patch)
 
 
-@image_comparison(baseline_images=['image_cliprect'], style='mpl20')
+@image_comparison(['image_cliprect'], style='mpl20')
 def test_image_cliprect():
-    import matplotlib.patches as patches
-
     fig, ax = plt.subplots()
     d = [[1, 2], [3, 4]]
 
@@ -340,7 +384,7 @@ def test_image_cliprect():
     im.set_clip_path(rect)
 
 
-@image_comparison(baseline_images=['imshow'], remove_text=True, style='mpl20')
+@image_comparison(['imshow'], remove_text=True, style='mpl20')
 def test_imshow():
     fig, ax = plt.subplots()
     arr = np.arange(100).reshape((10, 10))
@@ -349,8 +393,36 @@ def test_imshow():
     ax.set_ylim(0, 3)
 
 
-@image_comparison(baseline_images=['no_interpolation_origin'],
-                  remove_text=True)
+@check_figures_equal(extensions=['png'])
+def test_imshow_10_10_1(fig_test, fig_ref):
+    # 10x10x1 should be the same as 10x10
+    arr = np.arange(100).reshape((10, 10, 1))
+    ax = fig_ref.subplots()
+    ax.imshow(arr[:, :, 0], interpolation="bilinear", extent=(1, 2, 1, 2))
+    ax.set_xlim(0, 3)
+    ax.set_ylim(0, 3)
+
+    ax = fig_test.subplots()
+    ax.imshow(arr, interpolation="bilinear", extent=(1, 2, 1, 2))
+    ax.set_xlim(0, 3)
+    ax.set_ylim(0, 3)
+
+
+def test_imshow_10_10_2():
+    fig, ax = plt.subplots()
+    arr = np.arange(200).reshape((10, 10, 2))
+    with pytest.raises(TypeError):
+        ax.imshow(arr)
+
+
+def test_imshow_10_10_5():
+    fig, ax = plt.subplots()
+    arr = np.arange(500).reshape((10, 10, 5))
+    with pytest.raises(TypeError):
+        ax.imshow(arr)
+
+
+@image_comparison(['no_interpolation_origin'], remove_text=True)
 def test_no_interpolation_origin():
     fig, axs = plt.subplots(2)
     axs[0].imshow(np.arange(100).reshape((2, 50)), origin="lower",
@@ -358,24 +430,21 @@ def test_no_interpolation_origin():
     axs[1].imshow(np.arange(100).reshape((2, 50)), interpolation='none')
 
 
-@image_comparison(baseline_images=['image_shift'], remove_text=True,
-                  extensions=['pdf', 'svg'])
+@image_comparison(['image_shift'], remove_text=True, extensions=['pdf', 'svg'])
 def test_image_shift():
-    from matplotlib.colors import LogNorm
-
     imgData = [[1 / x + 1 / y for x in range(1, 100)] for y in range(1, 100)]
     tMin = 734717.945208
     tMax = 734717.946366
 
     fig, ax = plt.subplots()
-    ax.imshow(imgData, norm=LogNorm(), interpolation='none',
+    ax.imshow(imgData, norm=colors.LogNorm(), interpolation='none',
               extent=(tMin, tMax, 1, 100))
     ax.set_aspect('auto')
 
 
 def test_image_edges():
-    f = plt.figure(figsize=[1, 1])
-    ax = f.add_axes([0, 0, 1, 1], frameon=False)
+    fig = plt.figure(figsize=[1, 1])
+    ax = fig.add_axes([0, 0, 1, 1], frameon=False)
 
     data = np.tile(np.arange(12), 15).reshape(20, 9)
 
@@ -390,7 +459,7 @@ def test_image_edges():
     ax.set_yticks([])
 
     buf = io.BytesIO()
-    f.savefig(buf, facecolor=(0, 1, 0))
+    fig.savefig(buf, facecolor=(0, 1, 0))
 
     buf.seek(0)
 
@@ -401,9 +470,8 @@ def test_image_edges():
     assert g != 100, 'Expected a non-green edge - but sadly, it was.'
 
 
-@image_comparison(baseline_images=['image_composite_background'],
-                  remove_text=True,
-                  style='mpl20')
+@image_comparison(['image_composite_background'],
+                  remove_text=True, style='mpl20')
 def test_image_composite_background():
     fig, ax = plt.subplots()
     arr = np.arange(12).reshape(4, 3)
@@ -413,8 +481,7 @@ def test_image_composite_background():
     ax.set_xlim([0, 12])
 
 
-@image_comparison(baseline_images=['image_composite_alpha'],
-                  remove_text=True)
+@image_comparison(['image_composite_alpha'], remove_text=True)
 def test_image_composite_alpha():
     """
     Tests that the alpha value is recognized and correctly applied in the
@@ -441,9 +508,8 @@ def test_image_composite_alpha():
     ax.set_ylim([5, 0])
 
 
-@image_comparison(baseline_images=['rasterize_10dpi'],
-                  extensions=['pdf', 'svg'],
-                  remove_text=True, style='mpl20')
+@image_comparison(['rasterize_10dpi'],
+                  extensions=['pdf', 'svg'], remove_text=True, style='mpl20')
 def test_rasterize_dpi():
     # This test should check rasterized rendering with high output resolution.
     # It plots a rasterized line and a normal image with imshow.  So it will
@@ -453,19 +519,19 @@ def test_rasterize_dpi():
     # image_comparison.
     img = np.asarray([[1, 2], [3, 4]])
 
-    fig, axes = plt.subplots(1, 3, figsize=(3, 1))
+    fig, axs = plt.subplots(1, 3, figsize=(3, 1))
 
-    axes[0].imshow(img)
+    axs[0].imshow(img)
 
-    axes[1].plot([0, 1], [0, 1], linewidth=20., rasterized=True)
-    axes[1].set(xlim=(0, 1), ylim=(-1, 2))
+    axs[1].plot([0, 1], [0, 1], linewidth=20., rasterized=True)
+    axs[1].set(xlim=(0, 1), ylim=(-1, 2))
 
-    axes[2].plot([0, 1], [0, 1], linewidth=20.)
-    axes[2].set(xlim=(0, 1), ylim=(-1, 2))
+    axs[2].plot([0, 1], [0, 1], linewidth=20.)
+    axs[2].set(xlim=(0, 1), ylim=(-1, 2))
 
     # Low-dpi PDF rasterization errors prevent proper image comparison tests.
     # Hide detailed structures like the axes spines.
-    for ax in axes:
+    for ax in axs:
         ax.set_xticks([])
         ax.set_yticks([])
         for spine in ax.spines.values():
@@ -474,15 +540,15 @@ def test_rasterize_dpi():
     rcParams['savefig.dpi'] = 10
 
 
-@image_comparison(baseline_images=['bbox_image_inverted'], remove_text=True,
-                  style='mpl20')
+@image_comparison(['bbox_image_inverted'], remove_text=True, style='mpl20')
 def test_bbox_image_inverted():
     # This is just used to produce an image to feed to BboxImage
     image = np.arange(100).reshape((10, 10))
 
     fig, ax = plt.subplots()
     bbox_im = BboxImage(
-        TransformedBbox(Bbox([[100, 100], [0, 0]]), ax.transData))
+        TransformedBbox(Bbox([[100, 100], [0, 0]]), ax.transData),
+        interpolation='nearest')
     bbox_im.set_data(image)
     bbox_im.set_clip_on(False)
     ax.set_xlim(0, 100)
@@ -492,7 +558,8 @@ def test_bbox_image_inverted():
     image = np.identity(10)
 
     bbox_im = BboxImage(TransformedBbox(Bbox([[0.1, 0.2], [0.3, 0.25]]),
-                                        ax.figure.transFigure))
+                                        ax.figure.transFigure),
+                        interpolation='nearest')
     bbox_im.set_data(image)
     bbox_im.set_clip_on(False)
     ax.add_artist(bbox_im)
@@ -519,10 +586,8 @@ def test_get_window_extent_for_AxisImage():
     assert_array_equal(im_bbox.get_points(), [[400, 200], [700, 900]])
 
 
-@image_comparison(baseline_images=['zoom_and_clip_upper_origin'],
-                  remove_text=True,
-                  extensions=['png'],
-                  style='mpl20')
+@image_comparison(['zoom_and_clip_upper_origin.png'],
+                  remove_text=True, style='mpl20')
 def test_zoom_and_clip_upper_origin():
     image = np.arange(100)
     image = image.reshape((10, 10))
@@ -546,7 +611,6 @@ def test_nonuniformimage_setnorm():
 
 
 def test_jpeg_2d():
-    Image = pytest.importorskip('PIL.Image')
     # smoke test that mode-L pillow images work.
     imd = np.ones((10, 10), dtype='uint8')
     for i in range(10):
@@ -558,8 +622,6 @@ def test_jpeg_2d():
 
 
 def test_jpeg_alpha():
-    Image = pytest.importorskip('PIL.Image')
-
     plt.figure(figsize=(1, 1), dpi=300)
     # Create an image that is all black, with a gradient from 0-1 in
     # the alpha channel from left to right.
@@ -569,8 +631,7 @@ def test_jpeg_alpha():
     plt.figimage(im)
 
     buff = io.BytesIO()
-    with rc_context({'savefig.facecolor': 'red'}):
-        plt.savefig(buff, transparent=True, format='jpg', dpi=300)
+    plt.savefig(buff, facecolor="red", format='jpg', dpi=300)
 
     buff.seek(0)
     image = Image.open(buff)
@@ -584,17 +645,6 @@ def test_jpeg_alpha():
     assert corner_pixel == (254, 0, 0)
 
 
-def test_nonuniformimage_setdata():
-    ax = plt.gca()
-    im = NonUniformImage(ax)
-    x = np.arange(3, dtype=float)
-    y = np.arange(4, dtype=float)
-    z = np.arange(12, dtype=float).reshape((4, 3))
-    im.set_data(x, y, z)
-    x[0] = y[0] = z[0, 0] = 9.9
-    assert im._A[0, 0] == im._Ax[0] == im._Ay[0] == 0, 'value changed'
-
-
 def test_axesimage_setdata():
     ax = plt.gca()
     im = AxesImage(ax)
@@ -613,15 +663,20 @@ def test_figureimage_setdata():
     assert im._A[0, 0] == 0, 'value changed'
 
 
-def test_pcolorimage_setdata():
+@pytest.mark.parametrize(
+    "image_cls,x,y,a", [
+        (NonUniformImage,
+         np.arange(3.), np.arange(4.), np.arange(12.).reshape((4, 3))),
+        (PcolorImage,
+         np.arange(3.), np.arange(4.), np.arange(6.).reshape((3, 2))),
+    ])
+def test_setdata_xya(image_cls, x, y, a):
     ax = plt.gca()
-    im = PcolorImage(ax)
-    x = np.arange(3, dtype=float)
-    y = np.arange(4, dtype=float)
-    z = np.arange(6, dtype=float).reshape((3, 2))
-    im.set_data(x, y, z)
-    x[0] = y[0] = z[0, 0] = 9.9
+    im = image_cls(ax)
+    im.set_data(x, y, a)
+    x[0] = y[0] = a[0, 0] = 9.9
     assert im._A[0, 0] == im._Ax[0] == im._Ay[0] == 0, 'value changed'
+    im.set_data(x, y, a.reshape((*a.shape, -1)))  # Just a smoketest.
 
 
 def test_minimized_rasterized():
@@ -657,28 +712,28 @@ def test_minimized_rasterized():
                 assert False
 
 
-@pytest.mark.network
 def test_load_from_url():
-    url = "http://matplotlib.org/_static/logo_sidebar_horiz.png"
+    path = Path(__file__).parent / "baseline_images/test_image/imshow.png"
+    url = ('file:'
+           + ('///' if sys.platform == 'win32' else '')
+           + path.resolve().as_posix())
     plt.imread(url)
-    plt.imread(urllib.request.urlopen(url))
+    with urllib.request.urlopen(url) as file:
+        plt.imread(file)
 
 
-@image_comparison(baseline_images=['log_scale_image'],
-                  remove_text=True)
-# The recwarn fixture captures a warning in image_comparison.
-def test_log_scale_image(recwarn):
+@image_comparison(['log_scale_image'], remove_text=True)
+def test_log_scale_image():
     Z = np.zeros((10, 10))
     Z[::2] = 1
 
     fig, ax = plt.subplots()
-    ax.imshow(Z, extent=[1, 100, 1, 100], cmap='viridis',
-              vmax=1, vmin=-1)
-    ax.set_yscale('log')
+    ax.imshow(Z, extent=[1, 100, 1, 100], cmap='viridis', vmax=1, vmin=-1,
+              aspect='auto')
+    ax.set(yscale='log')
 
 
-@image_comparison(baseline_images=['rotate_image'],
-                  remove_text=True)
+@image_comparison(['rotate_image'], remove_text=True)
 def test_rotate_image():
     delta = 0.25
     x = y = np.arange(-3.0, 3.0, delta)
@@ -740,8 +795,7 @@ def test_image_preserve_size2():
                        np.identity(n, bool)[::-1])
 
 
-@image_comparison(baseline_images=['mask_image_over_under'],
-                  remove_text=True, extensions=['png'])
+@image_comparison(['mask_image_over_under.png'], remove_text=True)
 def test_mask_image_over_under():
     delta = 0.025
     x = y = np.arange(-3.0, 3.0, delta)
@@ -755,7 +809,7 @@ def test_mask_image_over_under():
     palette.set_over('r', 1.0)
     palette.set_under('g', 1.0)
     palette.set_bad('b', 1.0)
-    Zm = ma.masked_where(Z > 1.2, Z)
+    Zm = np.ma.masked_where(Z > 1.2, Z)
     fig, (ax1, ax2) = plt.subplots(1, 2)
     im = ax1.imshow(Zm, interpolation='bilinear',
                     cmap=palette,
@@ -775,8 +829,7 @@ def test_mask_image_over_under():
                  orientation='horizontal', ax=ax2, aspect=10)
 
 
-@image_comparison(baseline_images=['mask_image'],
-                  remove_text=True)
+@image_comparison(['mask_image'], remove_text=True)
 def test_mask_image():
     # Test mask image two ways: Using nans and using a masked array.
 
@@ -794,8 +847,15 @@ def test_mask_image():
     ax2.imshow(A, interpolation='nearest')
 
 
-@image_comparison(baseline_images=['imshow_endianess'],
-                  remove_text=True, extensions=['png'])
+def test_mask_image_all():
+    # Test behavior with an image that is entirely masked does not warn
+    data = np.full((2, 2), np.nan)
+    fig, ax = plt.subplots()
+    ax.imshow(data)
+    fig.canvas.draw_idle()  # would emit a warning
+
+
+@image_comparison(['imshow_endianess.png'], remove_text=True)
 def test_imshow_endianess():
     x = np.arange(10)
     X, Y = np.meshgrid(x, x)
@@ -809,8 +869,8 @@ def test_imshow_endianess():
     ax2.imshow(Z.astype('>f8'), **kwargs)
 
 
-@image_comparison(baseline_images=['imshow_masked_interpolation'],
-                  tol={'aarch64': 0.02}.get(platform.machine(), 0.0),
+@image_comparison(['imshow_masked_interpolation'],
+                  tol=0 if platform.machine() == 'x86_64' else 0.01,
                   remove_text=True, style='mpl20')
 def test_imshow_masked_interpolation():
 
@@ -822,7 +882,7 @@ def test_imshow_masked_interpolation():
     N = 20
     n = colors.Normalize(vmin=0, vmax=N*N-1)
 
-    data = np.arange(N*N, dtype='float').reshape(N, N)
+    data = np.arange(N*N, dtype=float).reshape(N, N)
 
     data[5, 5] = -1
     # This will cause crazy ringing for the higher-order
@@ -839,18 +899,17 @@ def test_imshow_masked_interpolation():
     data = np.ma.masked_array(data, mask)
 
     fig, ax_grid = plt.subplots(3, 6)
+    interps = sorted(mimage._interpd_)
+    interps.remove('antialiased')
 
-    for interp, ax in zip(sorted(mimage._interpd_), ax_grid.ravel()):
+    for interp, ax in zip(interps, ax_grid.ravel()):
         ax.set_title(interp)
         ax.imshow(data, norm=n, cmap=cm, interpolation=interp)
         ax.axis('off')
 
 
 def test_imshow_no_warn_invalid():
-    with warnings.catch_warnings(record=True) as warns:
-        warnings.simplefilter("always")
-        plt.imshow([[1, 2], [3, np.nan]])
-    assert len(warns) == 0
+    plt.imshow([[1, 2], [3, np.nan]])  # Check that no warning is emitted.
 
 
 @pytest.mark.parametrize(
@@ -874,19 +933,16 @@ def test_imshow_clips_rgb_to_valid_range(dtype):
         assert out.dtype == np.uint8
 
 
-@image_comparison(baseline_images=['imshow_flatfield'],
-                  remove_text=True, style='mpl20',
-                  extensions=['png'])
+@image_comparison(['imshow_flatfield.png'], remove_text=True, style='mpl20')
 def test_imshow_flatfield():
     fig, ax = plt.subplots()
-    im = ax.imshow(np.ones((5, 5)))
+    im = ax.imshow(np.ones((5, 5)), interpolation='nearest')
     im.set_clim(.5, 1.5)
 
 
-@image_comparison(baseline_images=['imshow_bignumbers'],
-                  remove_text=True, style='mpl20',
-                  extensions=['png'])
+@image_comparison(['imshow_bignumbers.png'], remove_text=True, style='mpl20')
 def test_imshow_bignumbers():
+    rcParams['image.interpolation'] = 'nearest'
     # putting a big number in an array of integers shouldn't
     # ruin the dynamic range of the resolved bits.
     fig, ax = plt.subplots()
@@ -895,10 +951,10 @@ def test_imshow_bignumbers():
     pc.set_clim(0, 5)
 
 
-@image_comparison(baseline_images=['imshow_bignumbers_real'],
-                  remove_text=True, style='mpl20',
-                  extensions=['png'])
+@image_comparison(['imshow_bignumbers_real.png'],
+                  remove_text=True, style='mpl20')
 def test_imshow_bignumbers_real():
+    rcParams['image.interpolation'] = 'nearest'
     # putting a big number in an array of integers shouldn't
     # ruin the dynamic range of the resolved bits.
     fig, ax = plt.subplots()
@@ -915,9 +971,8 @@ def test_imshow_bignumbers_real():
      lambda: colors.PowerNorm(1)])
 def test_empty_imshow(make_norm):
     fig, ax = plt.subplots()
-    with warnings.catch_warnings():
-        warnings.filterwarnings(
-            "ignore", "Attempting to set identical left==right")
+    with pytest.warns(UserWarning,
+                      match="Attempting to set identical left == right"):
         im = ax.imshow([[]], norm=make_norm())
     im.set_extent([-5, 5, -5, 5])
     fig.canvas.draw()
@@ -941,13 +996,10 @@ def test_imshow_bool():
 
 
 def test_full_invalid():
-    x = np.ones((10, 10))
-    x[:] = np.nan
-
-    f, ax = plt.subplots()
-    ax.imshow(x)
-
-    f.canvas.draw()
+    fig, ax = plt.subplots()
+    ax.imshow(np.full((10, 10), np.nan))
+    with pytest.warns(UserWarning):
+        fig.canvas.draw()
 
 
 @pytest.mark.parametrize("fmt,counted",
@@ -977,18 +1029,34 @@ def test_relim():
     assert ax.get_xlim() == ax.get_ylim() == (0, 1)
 
 
-def test_deprecation():
-    data = [[1, 2], [3, 4]]
-    ax = plt.figure().subplots()
-    for obj in [ax, plt]:
-        with pytest.warns(None) as record:
-            obj.imshow(data)
-            assert len(record) == 0
-        with pytest.warns(MatplotlibDeprecationWarning):
-            obj.imshow(data, shape=None)
-        with pytest.warns(MatplotlibDeprecationWarning):
-            # Enough arguments to pass "shape" positionally.
-            obj.imshow(data, *[None] * 10)
+def test_unclipped():
+    fig, ax = plt.subplots()
+    ax.set_axis_off()
+    im = ax.imshow([[0, 0], [0, 0]], aspect="auto", extent=(-10, 10, -10, 10),
+                   cmap='gray', clip_on=False)
+    ax.set(xlim=(0, 1), ylim=(0, 1))
+    fig.canvas.draw()
+    # The unclipped image should fill the *entire* figure and be black.
+    # Ignore alpha for this comparison.
+    assert (np.array(fig.canvas.buffer_rgba())[..., :3] == 0).all()
+
+
+def test_respects_bbox():
+    fig, axs = plt.subplots(2)
+    for ax in axs:
+        ax.set_axis_off()
+    im = axs[1].imshow([[0, 1], [2, 3]], aspect="auto", extent=(0, 1, 0, 1))
+    im.set_clip_path(None)
+    # Make the image invisible in axs[1], but visible in axs[0] if we pan
+    # axs[1] up.
+    im.set_clip_box(axs[0].bbox)
+    buf_before = io.BytesIO()
+    fig.savefig(buf_before, format="rgba")
+    assert {*buf_before.getvalue()} == {0xff}  # All white.
+    axs[1].set(ylim=(-1, 0))
+    buf_after = io.BytesIO()
+    fig.savefig(buf_after, format="rgba")
+    assert buf_before.getvalue() != buf_after.getvalue()  # Not all white.
 
 
 def test_image_cursor_formatting():
@@ -1004,3 +1072,76 @@ def test_image_cursor_formatting():
 
     data = np.nan
     assert im.format_cursor_data(data) == '[nan]'
+
+
+@check_figures_equal()
+def test_image_array_alpha(fig_test, fig_ref):
+    """Per-pixel alpha channel test."""
+    x = np.linspace(0, 1)
+    xx, yy = np.meshgrid(x, x)
+
+    zz = np.exp(- 3 * ((xx - 0.5) ** 2) + (yy - 0.7 ** 2))
+    alpha = zz / zz.max()
+
+    cmap = plt.get_cmap('viridis')
+    ax = fig_test.add_subplot(111)
+    ax.imshow(zz, alpha=alpha, cmap=cmap, interpolation='nearest')
+
+    ax = fig_ref.add_subplot(111)
+    rgba = cmap(colors.Normalize()(zz))
+    rgba[..., -1] = alpha
+    ax.imshow(rgba, interpolation='nearest')
+
+
+@pytest.mark.style('mpl20')
+def test_exact_vmin():
+    cmap = copy(plt.cm.get_cmap("autumn_r"))
+    cmap.set_under(color="lightgrey")
+
+    # make the image exactly 190 pixels wide
+    fig = plt.figure(figsize=(1.9, 0.1), dpi=100)
+    ax = fig.add_axes([0, 0, 1, 1])
+
+    data = np.array(
+        [[-1, -1, -1, 0, 0, 0, 0, 43, 79, 95, 66, 1, -1, -1, -1, 0, 0, 0, 34]],
+        dtype=float,
+    )
+
+    im = ax.imshow(data, aspect="auto", cmap=cmap, vmin=0, vmax=100)
+    ax.axis("off")
+    fig.canvas.draw()
+
+    # get the RGBA slice from the image
+    from_image = im.make_image(fig.canvas.renderer)[0][0]
+    # expand the input to be 190 long and run through norm / cmap
+    direct_computation = (
+        im.cmap(im.norm((data * ([[1]] * 10)).T.ravel())) * 255
+    ).astype(int)
+
+    # check than the RBGA values are the same
+    assert np.all(from_image == direct_computation)
+
+
+@pytest.mark.network
+@pytest.mark.flaky
+def test_https_imread_smoketest():
+    v = mimage.imread('https://matplotlib.org/1.5.0/_static/logo2.png')
+
+
+@check_figures_equal(extensions=['png'])
+def test_huge_range_log(fig_test, fig_ref):
+    data = np.full((5, 5), -1, dtype=np.float64)
+    data[0:2, :] = 1E20
+
+    ax = fig_test.subplots()
+    im = ax.imshow(data, norm=colors.LogNorm(vmin=100, vmax=data.max()),
+                   interpolation='nearest', cmap='viridis')
+
+    data = np.full((5, 5), -1, dtype=np.float64)
+    data[0:2, :] = 1000
+
+    cm = copy(plt.get_cmap('viridis'))
+    cm.set_under('w')
+    ax = fig_ref.subplots()
+    im = ax.imshow(data, norm=colors.Normalize(vmin=100, vmax=data.max()),
+                   interpolation='nearest', cmap=cm)
