@@ -1,15 +1,13 @@
-import unittest
-
 import numpy as np
 from numpy.testing import (assert_allclose, assert_almost_equal,
                            assert_array_equal, assert_array_almost_equal)
 import pytest
 
+from matplotlib import scale
 import matplotlib.pyplot as plt
 import matplotlib.patches as mpatches
 import matplotlib.transforms as mtransforms
 from matplotlib.path import Path
-from matplotlib.scale import LogScale
 from matplotlib.testing.decorators import image_comparison
 
 
@@ -17,7 +15,7 @@ def test_non_affine_caching():
     class AssertingNonAffineTransform(mtransforms.Transform):
         """
         This transform raises an assertion error when called when it
-        shouldn't be and self.raise_on_transform is True.
+        shouldn't be and ``self.raise_on_transform`` is True.
 
         """
         input_dims = output_dims = 2
@@ -52,7 +50,7 @@ def test_non_affine_caching():
 
 
 def test_external_transform_api():
-    class ScaledBy(object):
+    class ScaledBy:
         def __init__(self, scale_factor):
             self._scale_factor = scale_factor
 
@@ -69,7 +67,7 @@ def test_external_transform_api():
                     mtransforms.Affine2D().scale(10).get_matrix())
 
 
-@image_comparison(baseline_images=['pre_transform_data'],
+@image_comparison(['pre_transform_data'],
                   tol=0.08, remove_text=True, style='mpl20')
 def test_pre_transform_plotting():
     # a catch-all for as many as possible plot layouts which handle
@@ -121,7 +119,7 @@ def test_pcolor_pre_transform_limits():
     # Based on test_contour_pre_transform_limits()
     ax = plt.axes()
     xs, ys = np.meshgrid(np.linspace(15, 20, 15), np.linspace(12.4, 12.5, 20))
-    ax.pcolor(xs, ys, np.log(xs * ys),
+    ax.pcolor(xs, ys, np.log(xs * ys)[:-1, :-1],
               transform=mtransforms.Affine2D().scale(0.1) + ax.transData)
 
     expected = np.array([[1.5, 1.24],
@@ -133,7 +131,7 @@ def test_pcolormesh_pre_transform_limits():
     # Based on test_contour_pre_transform_limits()
     ax = plt.axes()
     xs, ys = np.meshgrid(np.linspace(15, 20, 15), np.linspace(12.4, 12.5, 20))
-    ax.pcolormesh(xs, ys, np.log(xs * ys),
+    ax.pcolormesh(xs, ys, np.log(xs * ys)[:-1, :-1],
                   transform=mtransforms.Affine2D().scale(0.1) + ax.transData)
 
     expected = np.array([[1.5, 1.24],
@@ -178,23 +176,30 @@ def test_Affine2D_from_values():
     assert_almost_equal(actual, expected)
 
 
+def test_affine_inverted_invalidated():
+    # Ensure that the an affine transform is not declared valid on access
+    point = [1.0, 1.0]
+    t = mtransforms.Affine2D()
+
+    assert_almost_equal(point, t.transform(t.inverted().transform(point)))
+    # Change and access the transform
+    t.translate(1.0, 1.0).get_matrix()
+    assert_almost_equal(point, t.transform(t.inverted().transform(point)))
+
+
 def test_clipping_of_log():
     # issue 804
-    M, L, C = Path.MOVETO, Path.LINETO, Path.CLOSEPOLY
-    points = [(0.2, -99), (0.4, -99), (0.4, 20), (0.2, 20), (0.2, -99)]
-    codes = [M, L, L, L, C]
-    path = Path(points, codes)
-
+    path = Path([(0.2, -99), (0.4, -99), (0.4, 20), (0.2, 20), (0.2, -99)],
+                closed=True)
     # something like this happens in plotting logarithmic histograms
-    trans = mtransforms.BlendedGenericTransform(mtransforms.Affine2D(),
-                                            LogScale.Log10Transform('clip'))
+    trans = mtransforms.BlendedGenericTransform(
+        mtransforms.Affine2D(), scale.LogTransform(10, 'clip'))
     tpath = trans.transform_path_non_affine(path)
     result = tpath.iter_segments(trans.get_affine(),
                                  clip=(0, 0, 100, 100),
                                  simplify=False)
-
     tpoints, tcodes = zip(*result)
-    assert_allclose(tcodes, [M, L, L, L, C])
+    assert_allclose(tcodes, path.codes)
 
 
 class NonAffineForTest(mtransforms.Transform):
@@ -219,8 +224,8 @@ class NonAffineForTest(mtransforms.Transform):
         return self.real_trans.transform_path(path)
 
 
-class BasicTransformTests(unittest.TestCase):
-    def setUp(self):
+class TestBasicTransform:
+    def setup_method(self):
 
         self.ta1 = mtransforms.Affine2D(shorthand_name='ta1').rotate(np.pi / 2)
         self.ta2 = mtransforms.Affine2D(shorthand_name='ta2').translate(10, 0)
@@ -352,10 +357,7 @@ class BasicTransformTests(unittest.TestCase):
         assert_array_equal(expected_result, result)
 
 
-class TestTransformPlotInterface(unittest.TestCase):
-    def tearDown(self):
-        plt.close()
-
+class TestTransformPlotInterface:
     def test_line_extent_axes_coords(self):
         # a simple line in axes coordinates
         ax = plt.axes()
@@ -381,7 +383,6 @@ class TestTransformPlotInterface(unittest.TestCase):
         assert_array_equal(ax.dataLim.get_points(),
                            np.array([[np.inf, -5.],
                                      [-np.inf, 35.]]))
-        plt.close()
 
     def test_line_extent_predata_transform_coords(self):
         # a simple line in (offset + data) coordinates
@@ -390,18 +391,16 @@ class TestTransformPlotInterface(unittest.TestCase):
         ax.plot([0.1, 1.2, 0.8], [35, -5, 18], transform=trans)
         assert_array_equal(ax.dataLim.get_points(),
                            np.array([[1., -50.], [12., 350.]]))
-        plt.close()
 
     def test_line_extent_compound_coords2(self):
         # a simple line in (offset + data) coordinates in the y component, and
         # in axes coordinates in the x
         ax = plt.axes()
-        trans = mtransforms.blended_transform_factory(ax.transAxes,
-            mtransforms.Affine2D().scale(10) + ax.transData)
+        trans = mtransforms.blended_transform_factory(
+            ax.transAxes, mtransforms.Affine2D().scale(10) + ax.transData)
         ax.plot([0.1, 1.2, 0.8], [35, -5, 18], transform=trans)
         assert_array_equal(ax.dataLim.get_points(),
                            np.array([[np.inf, -50.], [-np.inf, 350.]]))
-        plt.close()
 
     def test_line_extents_affine(self):
         ax = plt.axes()
@@ -489,6 +488,71 @@ def test_bbox_as_strings():
         assert eval(format(getattr(b, k), fmt)) == v
 
 
+def test_str_transform():
+    # The str here should not be considered as "absolutely stable", and may be
+    # reformatted later; this is just a smoketest for __str__.
+    assert str(plt.subplot(projection="polar").transData) == """\
+CompositeGenericTransform(
+    CompositeGenericTransform(
+        CompositeGenericTransform(
+            TransformWrapper(
+                BlendedAffine2D(
+                    IdentityTransform(),
+                    IdentityTransform())),
+            CompositeAffine2D(
+                Affine2D(
+                    [[1. 0. 0.]
+                     [0. 1. 0.]
+                     [0. 0. 1.]]),
+                Affine2D(
+                    [[1. 0. 0.]
+                     [0. 1. 0.]
+                     [0. 0. 1.]]))),
+        PolarTransform(
+            PolarAxesSubplot(0.125,0.1;0.775x0.8),
+            use_rmin=True,
+            _apply_theta_transforms=False)),
+    CompositeGenericTransform(
+        CompositeGenericTransform(
+            PolarAffine(
+                TransformWrapper(
+                    BlendedAffine2D(
+                        IdentityTransform(),
+                        IdentityTransform())),
+                LockableBbox(
+                    Bbox(x0=0.0, y0=0.0, x1=6.283185307179586, y1=1.0),
+                    [[-- --]
+                     [-- --]])),
+            BboxTransformFrom(
+                _WedgeBbox(
+                    (0.5, 0.5),
+                    TransformedBbox(
+                        Bbox(x0=0.0, y0=0.0, x1=6.283185307179586, y1=1.0),
+                        CompositeAffine2D(
+                            Affine2D(
+                                [[1. 0. 0.]
+                                 [0. 1. 0.]
+                                 [0. 0. 1.]]),
+                            Affine2D(
+                                [[1. 0. 0.]
+                                 [0. 1. 0.]
+                                 [0. 0. 1.]]))),
+                    LockableBbox(
+                        Bbox(x0=0.0, y0=0.0, x1=6.283185307179586, y1=1.0),
+                        [[-- --]
+                         [-- --]])))),
+        BboxTransformTo(
+            TransformedBbox(
+                Bbox(x0=0.125, y0=0.09999999999999998, x1=0.9, y1=0.9),
+                BboxTransformTo(
+                    TransformedBbox(
+                        Bbox(x0=0.0, y0=0.0, x1=8.0, y1=6.0),
+                        Affine2D(
+                            [[80.  0.  0.]
+                             [ 0. 80.  0.]
+                             [ 0.  0.  1.]])))))))"""
+
+
 def test_transform_single_point():
     t = mtransforms.Affine2D()
     r = t.transform_affine((1, 1))
@@ -559,8 +623,7 @@ def test_invalid_arguments():
 
 def test_transformed_path():
     points = [(0, 0), (1, 0), (1, 1), (0, 1)]
-    codes = [Path.MOVETO, Path.LINETO, Path.LINETO, Path.CLOSEPOLY]
-    path = Path(points, codes)
+    path = Path(points, closed=True)
 
     trans = mtransforms.Affine2D()
     trans_path = mtransforms.TransformedPath(path, trans)
