@@ -15,9 +15,11 @@ Matplotlib recognizes the following formats to specify a color:
   case-insensitive);
 * a string representation of a float value in ``[0, 1]`` inclusive for gray
   level (e.g., ``'0.5'``);
-* one of ``{'b', 'g', 'r', 'c', 'm', 'y', 'k', 'w'}``, they are the single
-  character short-hand notations for blue, green, red, cyan, magenta, yellow,
-  black, and white.
+* one of the characters ``{'b', 'g', 'r', 'c', 'm', 'y', 'k', 'w'}``, which
+  are short-hand notations for shades of blue, green, red, cyan, magenta,
+  yellow, black, and white. Note that the colors ``'g', 'c', 'm', 'y'`` do not
+  coincide with the X11/CSS4 colors. Their particular shades were chosen for
+  better visibility of colored lines against typical backgrounds.
 * a X11/CSS4 color name (case-insensitive);
 * a name from the `xkcd color survey`_, prefixed with ``'xkcd:'`` (e.g.,
   ``'xkcd:sky blue'``; case insensitive);
@@ -26,9 +28,9 @@ Matplotlib recognizes the following formats to specify a color:
   'tab:purple', 'tab:brown', 'tab:pink', 'tab:gray', 'tab:olive', 'tab:cyan'}``
   (case-insensitive);
 * a "CN" color spec, i.e. ``'C'`` followed by a number, which is an index into
-  the default property cycle (``matplotlib.rcParams['axes.prop_cycle']``); the
-  indexing is intended to occur at rendering time, and defaults to black if the
-  cycle does not include color.
+  the default property cycle (:rc:`axes.prop_cycle`); the indexing is intended
+  to occur at rendering time, and defaults to black if the cycle does not
+  include color.
 
 .. _xkcd color survey: https://xkcd.com/color/rgb/
 
@@ -81,7 +83,7 @@ demo('seaborn')
 
 ###############################################################################
 # will use the first color for the title and then plot using the second
-# and third colors of each style's ``mpl.rcParams['axes.prop_cycle']``.
+# and third colors of each style's :rc:`axes.prop_cycle`.
 #
 #
 # .. _xkcd-colors:
