@@ -10,16 +10,16 @@ Annotating text with Matplotlib.
 .. _annotations-tutorial:
 
 Basic annotation
-================
+----------------
 
 The uses of the basic :func:`~matplotlib.pyplot.text` will place text
 at an arbitrary position on the Axes.  A common use case of text is to
 annotate some feature of the plot, and the
-:func:`~matplotlib.Axes.annotate` method provides helper functionality
+:func:`~matplotlib.axes.Axes.annotate` method provides helper functionality
 to make annotations easy.  In an annotation, there are two points to
 consider: the location being annotated represented by the argument
-``xy`` and the location of the text ``xytext``.  Both of these
-arguments are ``(x,y)`` tuples.
+*xy* and the location of the text *xytext*.  Both of these
+arguments are ``(x, y)`` tuples.
 
 .. figure:: ../../gallery/pyplots/images/sphx_glr_annotation_basic_001.png
    :target: ../../gallery/pyplots/annotation_basic.html
@@ -28,23 +28,23 @@ arguments are ``(x,y)`` tuples.
 
    Annotation Basic
 
-In this example, both the ``xy`` (arrow tip) and ``xytext`` locations
+In this example, both the *xy* (arrow tip) and *xytext* locations
 (text location) are in data coordinates.  There are a variety of other
 coordinate systems one can choose -- you can specify the coordinate
-system of ``xy`` and ``xytext`` with one of the following strings for
-``xycoords`` and ``textcoords`` (default is 'data')
+system of *xy* and *xytext* with one of the following strings for
+*xycoords* and *textcoords* (default is 'data')
 
-====================  ====================================================
-argument              coordinate system
-====================  ====================================================
-  'figure points'     points from the lower left corner of the figure
-  'figure pixels'     pixels from the lower left corner of the figure
-  'figure fraction'   0,0 is lower left of figure and 1,1 is upper right
-  'axes points'       points from lower left corner of axes
-  'axes pixels'       pixels from lower left corner of axes
-  'axes fraction'     0,0 is lower left of axes and 1,1 is upper right
-  'data'              use the axes data coordinate system
-====================  ====================================================
+==================  ========================================================
+argument            coordinate system
+==================  ========================================================
+'figure points'     points from the lower left corner of the figure
+'figure pixels'     pixels from the lower left corner of the figure
+'figure fraction'   (0, 0) is lower left of figure and (1, 1) is upper right
+'axes points'       points from lower left corner of axes
+'axes pixels'       pixels from lower left corner of axes
+'axes fraction'     (0, 0) is lower left of axes and (1, 1) is upper right
+'data'              use the axes data coordinate system
+==================  ========================================================
 
 For example to place the text coordinates in fractional axes
 coordinates, one could do::
@@ -60,11 +60,11 @@ bottom-left of the figure or axes.
 
 Optionally, you can enable drawing of an arrow from the text to the annotated
 point by giving a dictionary of arrow properties in the optional keyword
-argument ``arrowprops``.
+argument *arrowprops*.
 
 
 ==================== =====================================================
-``arrowprops`` key   description
+*arrowprops* key     description
 ==================== =====================================================
 width                the width of the arrow in points
 frac                 the fraction of the arrow length occupied by the head
@@ -77,12 +77,12 @@ shrink               move the tip and base some percent away from
 ==================== =====================================================
 
 
-In the example below, the ``xy`` point is in native coordinates
-(``xycoords`` defaults to 'data').  For a polar axes, this is in
+In the example below, the *xy* point is in native coordinates
+(*xycoords* defaults to 'data').  For a polar axes, this is in
 (theta, radius) space.  The text in this example is placed in the
 fractional figure coordinate system. :class:`matplotlib.text.Text`
-keyword args like ``horizontalalignment``, ``verticalalignment`` and
-``fontsize`` are passed from `~matplotlib.Axes.annotate` to the
+keyword arguments like *horizontalalignment*, *verticalalignment* and
+*fontsize* are passed from `~matplotlib.axes.Axes.annotate` to the
 ``Text`` instance.
 
 .. figure:: ../../gallery/pyplots/images/sphx_glr_annotation_polar_001.png
@@ -103,12 +103,11 @@ Do not proceed unless you have already read :ref:`annotations-tutorial`,
 
 .. _plotting-guide-annotation:
 
-Advanced Annotation
-===================
-
+Advanced Annotations
+--------------------
 
 Annotating with Text with Box
------------------------------
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
 Let's start with a simple example.
 
@@ -119,25 +118,20 @@ Let's start with a simple example.
 
    Annotate Text Arrow
 
+`~.Axes.text` takes a *bbox* keyword argument, which draws a box around the
+text::
 
-The :func:`~matplotlib.pyplot.text` function in the pyplot module (or
-text method of the Axes class) takes bbox keyword argument, and when
-given, a box around the text is drawn. ::
-
-    bbox_props = dict(boxstyle="rarrow,pad=0.3", fc="cyan", ec="b", lw=2)
-    t = ax.text(0, 0, "Direction", ha="center", va="center", rotation=45,
-                size=15,
-                bbox=bbox_props)
-
+    t = ax.text(
+        0, 0, "Direction", ha="center", va="center", rotation=45, size=15,
+        bbox=dict(boxstyle="rarrow,pad=0.3", fc="cyan", ec="b", lw=2))
 
 The patch object associated with the text can be accessed by::
 
     bb = t.get_bbox_patch()
 
-The return value is an instance of FancyBboxPatch and the patch
-properties like facecolor, edgewidth, etc. can be accessed and
-modified as usual. To change the shape of the box, use the *set_boxstyle*
-method. ::
+The return value is a `.FancyBboxPatch`; patch properties
+(facecolor, edgewidth, etc.) can be accessed and modified as usual.
+`.FancyBboxPatch.set_boxstyle` sets the box shape::
 
   bb.set_boxstyle("rarrow", pad=0.6)
 
@@ -165,36 +159,30 @@ keyword arguments. Currently, following box styles are implemented.
 
    Fancybox Demo
 
-
 Note that the attribute arguments can be specified within the style
 name with separating comma (this form can be used as "boxstyle" value
 of bbox argument when initializing the text instance) ::
 
    bb.set_boxstyle("rarrow,pad=0.6")
 
-
-
-
 Annotating with Arrow
----------------------
+~~~~~~~~~~~~~~~~~~~~~
 
-The :func:`~matplotlib.pyplot.annotate` function in the pyplot module
-(or annotate method of the Axes class) is used to draw an arrow
-connecting two points on the plot. ::
+`~.Axes.annotate` draws an arrow connecting two points in an axes::
 
     ax.annotate("Annotation",
                 xy=(x1, y1), xycoords='data',
                 xytext=(x2, y2), textcoords='offset points',
                 )
 
-This annotates a point at ``xy`` in the given coordinate (``xycoords``)
-with the text at ``xytext`` given in ``textcoords``. Often, the
+This annotates a point at *xy* in the given coordinate (*xycoords*)
+with the text at *xytext* given in *textcoords*. Often, the
 annotated point is specified in the *data* coordinate and the annotating
 text in *offset points*.
-See :func:`~matplotlib.pyplot.annotate` for available coordinate systems.
+See `~.Axes.annotate` for available coordinate systems.
 
-An arrow connecting two points (xy & xytext) can be optionally drawn by
-specifying the ``arrowprops`` argument. To draw only an arrow, use
+An arrow connecting *xy* to *xytext* can be optionally drawn by
+specifying the *arrowprops* argument. To draw only an arrow, use
 empty string as the first argument. ::
 
     ax.annotate("",
@@ -211,20 +199,15 @@ empty string as the first argument. ::
 
    Annotate Simple01
 
-The arrow drawing takes a few steps.
-
-1. a connecting path between two points are created. This is
-   controlled by ``connectionstyle`` key value.
-
-2. If patch object is given (*patchA* & *patchB*), the path is clipped to
-   avoid the patch.
-
-3. The path is further shrunk by given amount of pixels (*shrinkA*
-   & *shrinkB*)
-
-4. The path is transmuted to arrow patch, which is controlled by the
-   ``arrowstyle`` key value.
+The arrow is drawn as follows:
 
+1. A path connecting the two points is created, as specified by the
+   *connectionstyle* parameter.
+2. The path is clipped to avoid patches *patchA* and *patchB*, if these are
+   set.
+3. The path is further shrunk by *shrinkA* and *shrinkB* (in pixels).
+4. The path is transmuted to an arrow patch, as specified by the *arrowstyle*
+   parameter.
 
 .. figure:: ../../gallery/userdemo/images/sphx_glr_annotate_explain_001.png
    :target: ../../gallery/userdemo/annotate_explain.html
@@ -253,7 +236,7 @@ points). As will be discussed below, some arrow style options can only
 be used when the connecting path is a quadratic spline.
 
 The behavior of each connection style is (limitedly) demonstrated in the
-example below. (Warning : The behavior of the ``bar`` style is currently not
+example below. (Warning: The behavior of the ``bar`` style is currently not
 well defined, it may be changed in the future).
 
 .. figure:: ../../gallery/userdemo/images/sphx_glr_connectionstyle_demo_001.png
@@ -306,8 +289,8 @@ of the text by default.
 
    Annotate Simple02
 
-As in the text command, a box around the text can be drawn using
-the ``bbox`` argument.
+As with `~.Axes.text`, a box around the text can be drawn using the *bbox*
+argument.
 
 .. figure:: ../../gallery/userdemo/images/sphx_glr_annotate_simple03_001.png
    :target: ../../gallery/userdemo/annotate_simple03.html
@@ -318,8 +301,8 @@ the ``bbox`` argument.
 
 By default, the starting point is set to the center of the text
 extent.  This can be adjusted with ``relpos`` key value. The values
-are normalized to the extent of the text. For example, (0,0) means
-lower-left corner and (1,1) means top-right.
+are normalized to the extent of the text. For example, (0, 0) means
+lower-left corner and (1, 1) means top-right.
 
 .. figure:: ../../gallery/userdemo/images/sphx_glr_annotate_simple04_001.png
    :target: ../../gallery/userdemo/annotate_simple04.html
@@ -330,13 +313,13 @@ lower-left corner and (1,1) means top-right.
 
 
 Placing Artist at the anchored location of the Axes
----------------------------------------------------
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
-There are classes of artists that can be placed at an anchored location
-in the Axes. A common example is the legend.  This type of artist can
-be created by using the OffsetBox class. A few predefined classes are
-available in ``mpl_toolkits.axes_grid1.anchored_artists`` others in
-``matplotlib.offsetbox`` ::
+There are classes of artists that can be placed at an anchored
+location in the Axes.  A common example is the legend.  This type
+of artist can be created by using the `.OffsetBox` class. A few
+predefined classes are available in :mod:`matplotlib.offsetbox` and in
+:mod:`mpl_toolkits.axes_grid1.anchored_artists`. ::
 
     from matplotlib.offsetbox import AnchoredText
     at = AnchoredText("Figure 1a",
@@ -397,7 +380,7 @@ determined during the drawing time respecting the specified transform. ::
   from mpl_toolkits.axes_grid1.anchored_artists import AnchoredAuxTransformBox
 
   box = AnchoredAuxTransformBox(ax.transData, loc='upper left')
-  el = Ellipse((0,0), width=0.1, height=0.4, angle=30)  # in data coordinates!
+  el = Ellipse((0, 0), width=0.1, height=0.4, angle=30)  # in data coordinates!
   box.drawing_area.add_artist(el)
 
 The ellipse in the above example will have width and height
@@ -426,111 +409,108 @@ Note that unlike the legend, the ``bbox_transform`` is set
 to IdentityTransform by default.
 
 Using Complex Coordinates with Annotations
-------------------------------------------
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
 The Annotation in matplotlib supports several types of coordinates as
 described in :ref:`annotations-tutorial`. For an advanced user who wants
 more control, it supports a few other options.
 
- 1. :class:`~matplotlib.transforms.Transform` instance. For example, ::
+1. A `.Transform` instance.  For example, ::
 
-      ax.annotate("Test", xy=(0.5, 0.5), xycoords=ax.transAxes)
+     ax.annotate("Test", xy=(0.5, 0.5), xycoords=ax.transAxes)
 
-    is identical to ::
+   is identical to ::
 
-      ax.annotate("Test", xy=(0.5, 0.5), xycoords="axes fraction")
+     ax.annotate("Test", xy=(0.5, 0.5), xycoords="axes fraction")
 
-    With this, you can annotate a point in other axes. ::
+   This allows annotating a point in another axes::
 
-      ax1, ax2 = subplot(121), subplot(122)
-      ax2.annotate("Test", xy=(0.5, 0.5), xycoords=ax1.transData,
-                   xytext=(0.5, 0.5), textcoords=ax2.transData,
-                   arrowprops=dict(arrowstyle="->"))
+     ax1, ax2 = subplot(121), subplot(122)
+     ax2.annotate("Test", xy=(0.5, 0.5), xycoords=ax1.transData,
+                  xytext=(0.5, 0.5), textcoords=ax2.transData,
+                  arrowprops=dict(arrowstyle="->"))
 
- 2. :class:`~matplotlib.artist.Artist` instance. The xy value (or
-    xytext) is interpreted as a fractional coordinate of the bbox
-    (return value of *get_window_extent*) of the artist. ::
+2. An `.Artist` instance. The *xy* value (or *xytext*) is interpreted as a
+   fractional coordinate of the bbox (return value of *get_window_extent*) of
+   the artist::
 
-      an1 = ax.annotate("Test 1", xy=(0.5, 0.5), xycoords="data",
-                        va="center", ha="center",
-                        bbox=dict(boxstyle="round", fc="w"))
-      an2 = ax.annotate("Test 2", xy=(1, 0.5), xycoords=an1, # (1,0.5) of the an1's bbox
-                        xytext=(30,0), textcoords="offset points",
-                        va="center", ha="left",
-                        bbox=dict(boxstyle="round", fc="w"),
-                        arrowprops=dict(arrowstyle="->"))
+     an1 = ax.annotate("Test 1", xy=(0.5, 0.5), xycoords="data",
+                       va="center", ha="center",
+                       bbox=dict(boxstyle="round", fc="w"))
+     an2 = ax.annotate("Test 2", xy=(1, 0.5), xycoords=an1,  # (1, 0.5) of the an1's bbox
+                       xytext=(30, 0), textcoords="offset points",
+                       va="center", ha="left",
+                       bbox=dict(boxstyle="round", fc="w"),
+                       arrowprops=dict(arrowstyle="->"))
 
-    .. figure:: ../../gallery/userdemo/images/sphx_glr_annotate_simple_coord01_001.png
-       :target: ../../gallery/userdemo/annotate_simple_coord01.html
-       :align: center
-       :scale: 50
+   .. figure:: ../../gallery/userdemo/images/sphx_glr_annotate_simple_coord01_001.png
+      :target: ../../gallery/userdemo/annotate_simple_coord01.html
+      :align: center
+      :scale: 50
 
-       Annotation with Simple Coordinates
+      Annotation with Simple Coordinates
 
-    Note that it is your responsibility that the extent of the
-    coordinate artist (*an1* in above example) is determined before *an2*
-    gets drawn. In most cases, it means that *an2* needs to be drawn
-    later than *an1*.
+   Note that you must ensure that the extent of the coordinate artist (*an1* in
+   above example) is determined before *an2* gets drawn. Usually, this means
+   that *an2* needs to be drawn after *an1*.
 
+3. A callable object that takes the renderer instance as single argument, and
+   returns either a `.Transform` or a `.BboxBase`.  The return value is then
+   handled as in (1), for transforms, or in (2), for bboxes.  For example, ::
 
- 3. A callable object that returns an instance of either
-    :class:`~matplotlib.transforms.BboxBase` or
-    :class:`~matplotlib.transforms.Transform`. If a transform is
-    returned, it is the same as 1 and if a bbox is returned, it is the same
-    as 2.  The callable object should take a single argument of the
-    renderer instance. For example, the following two commands give
-    identical results ::
+     an2 = ax.annotate("Test 2", xy=(1, 0.5), xycoords=an1,
+                       xytext=(30, 0), textcoords="offset points")
 
-      an2 = ax.annotate("Test 2", xy=(1, 0.5), xycoords=an1,
-                        xytext=(30,0), textcoords="offset points")
-      an2 = ax.annotate("Test 2", xy=(1, 0.5), xycoords=an1.get_window_extent,
-                        xytext=(30,0), textcoords="offset points")
+   is identical to::
 
+     an2 = ax.annotate("Test 2", xy=(1, 0.5), xycoords=an1.get_window_extent,
+                       xytext=(30, 0), textcoords="offset points")
 
- 4. A tuple of two coordinate specifications. The first item is for the
-    x-coordinate and the second is for the y-coordinate. For example, ::
+4. A pair of coordinate specifications -- the first for the x-coordinate, and
+   the second is for the y-coordinate; e.g. ::
 
-      annotate("Test", xy=(0.5, 1), xycoords=("data", "axes fraction"))
+     annotate("Test", xy=(0.5, 1), xycoords=("data", "axes fraction"))
 
-    0.5 is in data coordinates, and 1 is in normalized axes coordinates.
-    You may use an artist or transform as with a tuple. For example,
+   Here, 0.5 is in data coordinates, and 1 is in normalized axes coordinates.
+   Each of the coordinate specifications can also be an artist or a transform.
+   For example,
 
-    .. figure:: ../../gallery/userdemo/images/sphx_glr_annotate_simple_coord02_001.png
-       :target: ../../gallery/userdemo/annotate_simple_coord02.html
-       :align: center
-       :scale: 50
+   .. figure:: ../../gallery/userdemo/images/sphx_glr_annotate_simple_coord02_001.png
+      :target: ../../gallery/userdemo/annotate_simple_coord02.html
+      :align: center
+      :scale: 50
 
-       Annotation with Simple Coordinates 2
+      Annotation with Simple Coordinates 2
 
- 5. Sometimes, you want your annotation with some "offset points", not from the
-    annotated point but from some other point.
-    :class:`~matplotlib.text.OffsetFrom` is a helper class for such cases.
+5. Sometimes, you want your annotation with some "offset points", not from the
+   annotated point but from some other point.  `.text.OffsetFrom` is a helper
+   for such cases.
 
-    .. figure:: ../../gallery/userdemo/images/sphx_glr_annotate_simple_coord03_001.png
-       :target: ../../gallery/userdemo/annotate_simple_coord03.html
-       :align: center
-       :scale: 50
+   .. figure:: ../../gallery/userdemo/images/sphx_glr_annotate_simple_coord03_001.png
+      :target: ../../gallery/userdemo/annotate_simple_coord03.html
+      :align: center
+      :scale: 50
 
-       Annotation with Simple Coordinates 3
+      Annotation with Simple Coordinates 3
 
-    You may take a look at this example
-    :doc:`/gallery/text_labels_and_annotations/annotation_demo`.
+   You may take a look at this example
+   :doc:`/gallery/text_labels_and_annotations/annotation_demo`.
 
 Using ConnectionPatch
----------------------
+~~~~~~~~~~~~~~~~~~~~~
 
-The ConnectionPatch is like an annotation without text. While the annotate
-function is recommended in most situations, the ConnectionPatch is useful when
-you want to connect points in different axes. ::
+ConnectionPatch is like an annotation without text. While `~.Axes.annotate`
+is sufficient in most situations, ConnectionPatch is useful when you want to
+connect points in different axes. ::
 
   from matplotlib.patches import ConnectionPatch
   xy = (0.2, 0.2)
-  con = ConnectionPatch(xyA=xy, xyB=xy, coordsA="data", coordsB="data",
-                        axesA=ax1, axesB=ax2)
-  ax2.add_artist(con)
+  con = ConnectionPatch(xyA=xy, coordsA=ax1.transData,
+                        xyB=xy, coordsB=ax2.transData)
+  fig.add_artist(con)
 
-The above code connects point xy in the data coordinates of ``ax1`` to
-point xy in the data coordinates of ``ax2``. Here is a simple example.
+The above code connects point *xy* in the data coordinates of ``ax1`` to
+point *xy* in the data coordinates of ``ax2``. Here is a simple example.
 
 .. figure:: ../../gallery/userdemo/images/sphx_glr_connect_simple01_001.png
    :target: ../../gallery/userdemo/connect_simple01.html
@@ -539,23 +519,20 @@ point xy in the data coordinates of ``ax2``. Here is a simple example.
 
    Connect Simple01
 
-
-While the ConnectionPatch instance can be added to any axes, you may want to add
-it to the axes that is latest in drawing order to prevent overlap by other
-axes.
-
+Here, we added the ConnectionPatch to the *figure* (with `~.Figure.add_artist`)
+rather than to either axes: this ensures that it is drawn on top of both axes,
+and is also necessary if using :doc:`constrained_layout
+</tutorials/intermediate/constrainedlayout_guide>` for positioning the axes.
 
 Advanced Topics
-~~~~~~~~~~~~~~~
+---------------
 
 Zoom effect between Axes
-------------------------
-
-``mpl_toolkits.axes_grid1.inset_locator`` defines some patch classes useful
-for interconnecting two axes. Understanding the code requires some
-knowledge of how mpl's transform works. But, utilizing it will be
-straight forward.
+~~~~~~~~~~~~~~~~~~~~~~~~
 
+``mpl_toolkits.axes_grid1.inset_locator`` defines some patch classes useful for
+interconnecting two axes. Understanding the code requires some knowledge of
+Matplotlib's transform system.
 
 .. figure:: ../../gallery/subplots_axes_and_figures/images/sphx_glr_axes_zoom_effect_001.png
    :target: ../../gallery/subplots_axes_and_figures/axes_zoom_effect.html
@@ -564,9 +541,8 @@ straight forward.
 
    Axes Zoom Effect
 
-
 Define Custom BoxStyle
-----------------------
+~~~~~~~~~~~~~~~~~~~~~~
 
 You can use a custom box style. The value for the ``boxstyle`` can be a
 callable object in the following forms.::
@@ -593,17 +569,6 @@ Here is a complete example.
 
    Custom Boxstyle01
 
-However, it is recommended that you derive from the
-matplotlib.patches.BoxStyle._Base as demonstrated below.
-
-.. figure:: ../../gallery/userdemo/images/sphx_glr_custom_boxstyle02_001.png
-   :target: ../../gallery/userdemo/custom_boxstyle02.html
-   :align: center
-   :scale: 50
-
-   Custom Boxstyle02
-
-
 Similarly, you can define a custom ConnectionStyle and a custom ArrowStyle.
 See the source code of ``lib/matplotlib/patches.py`` and check
 how each style class is defined.
